* energy_trade_paper.do

* Copyright 2007 Gernot Wagner, some rights reserved. All Stata files are licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 2.5 License. You are free to use them for any non-commercial purposes, as long as you give credit and share alike.
* See http://www.gwagner.net/about/copyright.html for more information.

***
* Energy content of trade EKC analysis
***

* input: energy_trade_paper.dta


clear
use energy_trade_paper.dta

**
* accounting example
**

* U.S. example

gen GDP = PWT_GDPplcap * PWT_population / 1000000

* edit year ccode country valueadded output GDP industry_oil industry_oilperY industry_total industry_energyperY oilCONSUMbarrels oilPRODbarrels energyCONSUMbarrels energyPRODbarrels if ccode == 840
* edit year ccode country valueadded output GDP industry_oil industry_oilperY industry_total industry_energyperY oilCONSUMbarrels oilPRODbarrels energyCONSUMbarrels energyPRODbarrels if ccode == 40
* edit year ccode country valueadded output GDP industry_oil industry_oilperY industry_total industry_energyperY oilCONSUMbarrels oilPRODbarrels energyCONSUMbarrels energyPRODbarrels if ccode == 156





**
* paper
**

* exposition in introduction:
* edit year ccode country tradeM tradeX oilMTdirectbarrels netoilMTdirectbarrels oilMTbarrels netoilMTbarrels energyMTbarrels if year == 2000 & ccode == 840

* Table I: trade and energy for US
* edit year oilMTdirectbarrels oilMTbarrels netoilMTdirectbarrels netoilMTbarrels energyMTdirectbarrels energyMTbarrels netenergyMTdirectbarrels netenergyMTbarrels if ccode == 840

bysort year: egen directoilTradebyYear = sum(oilMTdirectbarrels)
bysort year: egen oilTradebyYear = sum(oilMTbarrels)
gen indirectVSdirectRATIO = oilTradebyYear / directoilTradebyYear

* determine total direct and indirect oil trade by year:
* edit year directoilTradebyYear oilTradebyYear indirectVSdirectRATIO if ccode == 840
drop directoilTradebyYear oilTradebyYear indirectVSdirectRATIO

* determine US-Chinese trade/oil links:

preserve
use energy_trade_complete, clear
* edit year ccode1 ccode2 tradeM12 tradeM oilM12barrels oilMTbarrels energyM12barrels energyMTbarrels oilM12intensity oilMintensity energyM12intensity energyMintensity if ccode1 == 840 & ccode2 == 156
clear
restore


* EKC

gen PWT_GDPplcap2 = PWT_GDPplcap * PWT_GDPplcap
gen PWT_GDPplcap3 = PWT_GDPplcap * PWT_GDPplcap * PWT_GDPplcap

gen lnoilCONSUMbarrelscap = log(oilCONSUMbarrelscap)
gen lnoilPRODbarrelscap = log(oilPRODbarrelscap)
gen lnenergyCONSUMbarrelscap = log(energyCONSUMbarrelscap)
gen lnenergyPRODbarrelscap = log(energyPRODbarrelscap)

gen lnUSoilCONSUMbarrelscap = log(USoilCONSUMbarrelscap)
gen lnUSoilPRODbarrelscap = log(USoilPRODbarrelscap)
gen lnUSenergyCONSUMbarrelscap = log(USenergyCONSUMbarrelscap)
gen lnUSenergyPRODbarrelscap = log(USenergyPRODbarrelscap)
gen lnUS95oilCONSUMbarrelscap = log(US95oilCONSUMbarrelscap)
gen lnUS95oilPRODbarrelscap = log(US95oilPRODbarrelscap)
gen lnUS95energyCONSUMbarrelscap = log(US95energyCONSUMbarrelscap)
gen lnUS95energyPRODbarrelscap = log(US95energyPRODbarrelscap)

gen lnPWT_GDPplcap = log(PWT_GDPplcap)
gen lnPWT_GDPplcap2 = lnPWT_GDPplcap * lnPWT_GDPplcap
gen lnPWT_GDPplcap3 = lnPWT_GDPplcap * lnPWT_GDPplcap * lnPWT_GDPplcap

xi i.ccode i.year
tsset ccode year

log using energy_trade_paper_hettest, replace

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3


reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

log close

* --> clearly heteroscedastic, test statistics ranging from 80 to 247 for oil and 336 to 1036 for energy


log using energy_trade_paper_autocorr_test, replace

xtserial lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

xtserial lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2
xtserial lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

log close
* --> clear serial correlation









* Hausman test, fixed v random


xtreg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, fe
est store fixed
xtreg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, re
est store random
hausman fixed random



**********************
* standard version
**********************


* quadratic regressions

log using energy_trade_paper_reg_output, replace

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store oil1_R_c
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_c

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store oil1_R_p
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store energy1_R_c
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_c

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store energy1_R_p
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p




est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)


* calculate peaks

est restore oil3_c
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil3_p
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore energy3_c
* nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore energy3_p
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

log close


* quadratic graphs

est restore oil2_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil2_c and oil2_p")
graph export energy_trade_paper_oil2_c_p.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil3_c and oil3_p")
graph export energy_trade_paper_oil3_c_p.png, replace
drop oilCONSUMpred oilPRODpred

est restore energy2_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy2_c and energy2_p")
graph export energy_trade_paper_energy2_c_p.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy3_c and energy3_p")
graph export energy_trade_paper_energy3_c_p.png, replace
drop energyCONSUMpred energyPRODpred

est clear

log using energy_trade_paper_reg_output, append

* Hypotheses tests

* Quadratic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!


* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!


est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

* nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
* system limit exceeded!
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
* system limit exceeded!


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded


* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)

* calculate peaks

* nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
* max number of iterations exceeded
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded




log close
est clear




log using energy_trade_paper_reg_output_GDP3, replace

* cubic regressions

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store oil1_R_c_3
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_c_3

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store oil1_R_p_3
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_p_3



xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p_3


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p_3



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store energy1_R_c_3
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_c_3

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store energy1_R_p_3
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_p_3



xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p_3


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p_3




est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)

* calculate peaks

est restore oil3_c_3
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
est restore oil3_p_3
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

est restore energy3_c_3
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
est restore energy3_p_3
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

log close


* cubic graphs

est restore oil2_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil2_c_3 and oil2_p_3")
graph export energy_trade_paper_oil2_c_p_3.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil3_c_3 and oil3_p_3")
graph export energy_trade_paper_oil3_c_p_3.png, replace


* for paper, Fig 1a
twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("FGLS, AR(1)")
graph export Figure1a.png, replace
drop oilCONSUMpred oilPRODpred




est restore energy2_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy2_c_3 and energy2_p_3")
graph export energy_trade_paper_oil2_c_p_3.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy3_c_3 and energy3_p_3")
graph export energy_trade_paper_energy3_c_p_3.png, replace


* for paper, Fig 1b
twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("FGLS, AR(1)")
graph export Figure1b.png, replace
drop energyCONSUMpred energyPRODpred



log using energy_trade_paper_reg_output_GDP3, append
* Hypotheses tests

* Cubic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks
testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))


local sign_ag = sign((exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))) - (exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))))

display "H_0: cons peak >= prod peak. p-value = " normal(`sign_ag'*sqrt(r(chi2)))



* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))

local sign_ag = sign((exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))) - (exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))))

display "H_0: cons peak >= prod peak. p-value = " normal(`sign_ag'*sqrt(r(chi2)))


est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))

local sign_ag = sign((exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))) - (exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))))

display "H_0: cons peak >= prod peak. p-value = " normal(`sign_ag'*sqrt(r(chi2)))


* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))

local sign_ag = sign((exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))) - (exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))))

display "H_0: cons peak >= prod peak. p-value = " normal(`sign_ag'*sqrt(r(chi2)))


log close
est clear








**********************
* before 1996
**********************

* if year <= 1995


* quadratic regressions

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust
est store oil1_R_c
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store oil1_RC_c

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust
est store oil1_R_p
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store oil1_RC_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust
est store energy1_R_c
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store energy1_RC_c

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust
est store energy1_R_p
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store energy1_RC_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p



log using before1995/reg_output, replace

est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* quadratic graphs

est restore oil2_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("before 1995, oil2_c and oil2_p")
graph export before1995/oil2_c_p.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("before 1995, oil3_c and oil3_p")
graph export before1995/oil3_c_p.png, replace
drop oilCONSUMpred oilPRODpred

est restore energy2_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("before 1995, energy2_c and energy2_p")
graph export before1995/energy2_c_p.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("before 1995, energy3_c and energy3_p")
graph export before1995/energy3_c_p.png, replace
drop energyCONSUMpred energyPRODpred

est clear

log using before1995/reg_output, append

* Hypotheses tests

* Quadratic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))

* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients at 10% level


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))


est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if year <= 1995
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients, but not sensible, since no peak


* calculate peaks

nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
* system limit exceeded!


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded


* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients in first, not in second, but not sensible, since no different peaks

* calculate peaks

nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded




log close
est clear





* cubic regressions

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust
est store oil1_R_c_3
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store oil1_RC_c_3

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust
est store oil1_R_p_3
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store oil1_RC_p_3



xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p_3


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p_3



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust
est store energy1_R_c_3
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store energy1_RC_c_3

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust
est store energy1_R_p_3
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995, robust cluster(ccode)
est store energy1_RC_p_3



xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p_3


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if year <= 1995, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p_3



log using before1995/reg_output_GDP3, replace

est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* cubic graphs

est restore oil2_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("before 1995, oil2_c_3 and oil2_p_3")
graph export before1995/oil2_c_p_3.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("before 1995, oil3_c_3 and oil3_p_3")
graph export before1995/oil3_c_p_3.png, replace


* for paper, Fig 1a
twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("before 1995, FGLS, AR(1)")
graph export before1995/Figure1a.png, replace
drop oilCONSUMpred oilPRODpred




est restore energy2_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("before 1995, energy2_c_3 and energy2_p_3")
graph export before1995/energy2_c_p_3.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("before 1995, energy3_c_3 and energy3_p_3")
graph export before1995/energy3_c_p_3.png, replace


* for paper, Fig 1b
twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("before 1995, FGLS, AR(1)")
graph export before1995/Figure1b.png, replace
drop energyCONSUMpred energyPRODpred



log using before1995/reg_output_GDP3, append
* Hypotheses tests

* Cubic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))


* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))



est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if year <= 1995
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))
* --> same peaks

* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))

log close
est clear











**********************
* without USA
**********************

* if ccode ~= 840


* quadratic regressions

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust
est store oil1_R_c
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store oil1_RC_c

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust
est store oil1_R_p
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store oil1_RC_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust
est store energy1_R_c
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store energy1_RC_c

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust
est store energy1_R_p
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store energy1_RC_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p



log using noUSA/reg_output, replace

est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* quadratic graphs

est restore oil2_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("no USA, oil2_c and oil2_p")
graph export noUSA/oil2_c_p.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("no USA, oil3_c and oil3_p")
graph export noUSA/oil3_c_p.png, replace
drop oilCONSUMpred oilPRODpred

est restore energy2_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("no USA, energy2_c and energy2_p")
graph export noUSA/energy2_c_p.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("no USA, energy3_c and energy3_p")
graph export noUSA/energy3_c_p.png, replace
drop energyCONSUMpred energyPRODpred

est clear

log using noUSA/reg_output, append

* Hypotheses tests

* Quadratic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))
* --> max number of iterations exceeded

* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients at 10% level


* calculate peaks

nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))
* --> max number of iterations exceeded


est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear* if ccode ~= 840
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients, but not sensible, since no peak


* calculate peaks

nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
* system limit exceeded!


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded


* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
* --> different coefficients in first, not in second, but not sensible, since no different peaks

* calculate peaks

nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak
nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))
* --> not sensible, since no peak


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded




log close
est clear





* cubic regressions

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust
est store oil1_R_c_3
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store oil1_RC_c_3

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust
est store oil1_R_p_3
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store oil1_RC_p_3



xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p_3


xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c_3
xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p_3



reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust
est store energy1_R_c_3
reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store energy1_RC_c_3

reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust
est store energy1_R_p_3
reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840, robust cluster(ccode)
est store energy1_RC_p_3



xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p_3


xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c_3
xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode ~= 840, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p_3



log using noUSA/reg_output_GDP3, replace

est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* cubic graphs

est restore oil2_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("no USA, oil2_c_3 and oil2_p_3")
graph export noUSA/oil2_c_p_3.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil3_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("no USA, oil3_c_3 and oil3_p_3")
graph export noUSA/oil3_c_p_3.png, replace


* for paper, Fig 1a
twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("no USA, FGLS, AR(1)")
graph export noUSA/Figure1a.png, replace
drop oilCONSUMpred oilPRODpred




est restore energy2_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("no USA, energy2_c_3 and energy2_p_3")
graph export noUSA/energy2_c_p_3.png, replace
drop energyCONSUMpred energyPRODpred



est restore energy3_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("no USA, energy3_c_3 and energy3_p_3")
graph export noUSA/energy3_c_p_3.png, replace


* for paper, Fig 1b
twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("no USA, FGLS, AR(1)")
graph export noUSA/Figure1b.png, replace
drop energyCONSUMpred energyPRODpred



log using noUSA/reg_output_GDP3, append
* Hypotheses tests

* Cubic

* oil

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))


* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))



est clear
* energy

quietly reg lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840
quietly est store energy1_c
quietly reg lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear* if ccode ~= 840
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))
* --> same peaks

* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))

log close
est clear





save temp, replace


****

* determine most energy-efficient economy:

preserve
clear
use energy_trade_paper
keep year ccode country industry_oilperYbarrels
reshape wide industry_oilperYbarrels, i(ccode) j(year)
* edit
* analysis in Excel: intensities vary wildly --> use US intensities
restore


sort industry_oilperYbarrels
* edit year ccode country industry_oilperYbarrels industry_energyperYbarrels if year == 1995
* edit year ccode country industry_oilperYbarrels industry_energyperYbarrels if year == 2000
sort industry_energyperYbarrels
* edit year ccode country industry_oilperYbarrels industry_energyperYbarrels if year == 2000

sort year
* for paper, Fig 2a
twoway (scatter industry_oilperYbarrels year if ccode == 840, c(l) xlabel(#6) ylabel(#5) msymbol(o) xtitle("Year") ytitle("barrels of oil per million $ manufacturing output") legend(label(1 "USA"))) (scatter industry_oilperYbarrels year if ccode == 156, c(l) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "China"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Manufacturing oil intensity")
graph export Figure2a.png, replace

* for paper, Fig 2b
twoway (scatter industry_energyperYbarrels year if ccode == 840, c(l) xlabel(#6) ylabel(#5) msymbol(o) xtitle("Year") ytitle("barrels-equivalent per million $ manufacturing output") legend(label(1 "USA"))) (scatter industry_energyperYbarrels year if ccode == 156, c(l) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "China"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Manufacturing energy intensity")
graph export Figure2b.png, replace





sort industry_oilperYbarrels
* edit year ccode country industry_oilperYbarrels industry_energyperYbarrels if year == 1995

* (1) use U.S. intensities for all years
* (2) use U.S. intensities from 1995 for all countries and years

* --> create these intensities in energy_trade.do file, with prefixes US and US95


* explore data
sort ccode year
* edit year ccode country oilCONSUMbarrels oilPRODbarrels USoilCONSUMbarrels USoilPRODbarrels US95oilCONSUMbarrels US95oilPRODbarrels oilMintensity oilXintensity USoilMintensity USoilXintensity US95oilMintensity US95oilXintensity if ccode == 40 | ccode == 840






**
* hettest and bgodfrey for US95 intensities



log using US95intensities/hettest, replace

reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3


reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2

reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
hettest lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3

log close


* --> clearly heteroscedastic (--> oil and energy same)


* autocorrelation tested above --> autocorrelated



**********************
* regressions with US95 intensities
**********************


* quadratic regressions

reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store oil1_R_c
reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_c

reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store oil1_R_p
reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_p


xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c
xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p


xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c
xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p



reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store energy1_R_c
reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_c

reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust
est store energy1_R_p
reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_p


xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c
xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p


xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c
xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p



log using US95intensities/reg_output, replace

est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c oil1_RC_c oil1_R_p oil1_RC_p oil2_c oil2_p oil3_c oil3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c energy1_RC_c energy1_R_p energy1_RC_p energy2_c energy2_p energy3_c energy3_p, keep (lnPWT_GDPplcap lnPWT_GDPplcap2) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* quadratic graphs

est restore oil2_c
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp

twoway (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("US95 intensities, oil2_c and oil2_p")
graph export US95intensities/oil2_c_p.png, replace
drop US95oilCONSUMpred US95oilPRODpred



est restore oil3_c
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp

twoway (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("US95 intensities, oil3_c and oil3_p")
graph export US95intensities/oil3_c_p.png, replace
drop US95oilCONSUMpred US95oilPRODpred

est restore energy2_c
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp

twoway (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("US95 intensities, energy2_c and energy2_p")
graph export US95intensities/energy2_c_p.png, replace
drop US95energyCONSUMpred US95energyPRODpred



est restore energy3_c
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp

twoway (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("US95 intensities, energy3_c and energy3_p")
graph export US95intensities/energy3_c_p.png, replace
drop US95energyCONSUMpred US95energyPRODpred

est clear


* --> all upward-sloping!



log using US95intensities/reg_output, append

* Hypotheses tests

* Quadratic

* oil

quietly reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store oil1_c
quietly reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

* nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
* nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))

* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

* nlcom exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2))
* nlcom exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[oil1_p_mean]lnPWT_GDPplcap/(2 * [oil1_p_mean]lnPWT_GDPplcap2)) = exp(-[oil1_c_mean]lnPWT_GDPplcap/(2 * [oil1_c_mean]lnPWT_GDPplcap2)))


est clear
* energy

quietly reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store energy1_c
quietly reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 _Iccode* _Iyear*
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)


* calculate peaks

* nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))


* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2)

* calculate peaks

* nlcom exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2))
* nlcom exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2))


* test peaks

* testnl(exp(-[energy1_p_mean]lnPWT_GDPplcap/(2 * [energy1_p_mean]lnPWT_GDPplcap2)) = exp(-[energy1_c_mean]lnPWT_GDPplcap/(2 * [energy1_c_mean]lnPWT_GDPplcap2)))
* --> not sensible, since no peak, no sig regressions for quadratic!
* not possible: "max number of iterations exeeded




log close
est clear





* cubic regressions

reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store oil1_R_c_3
reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_c_3

reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store oil1_R_p_3
reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store oil1_RC_p_3



xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store oil2_c_3
xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store oil2_p_3


xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_c_3
xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store oil3_p_3



reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store energy1_R_c_3
reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_c_3

reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust
est store energy1_R_p_3
reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*, robust cluster(ccode)
est store energy1_RC_p_3



xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store energy2_c_3
xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
est store energy2_p_3


xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_c_3
xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
est store energy3_p_3



log using US95intensities/reg_output_GDP3, replace

est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table oil1_R_c_3 oil1_RC_c_3 oil1_R_p_3 oil1_RC_p_3 oil2_c_3 oil2_p_3 oil3_c_3 oil3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)


est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) se(%9.2f) stats(N)
est table energy1_R_c_3 energy1_RC_c_3 energy1_R_p_3 energy1_RC_p_3 energy2_c_3 energy2_p_3 energy3_c_3 energy3_p_3, keep (lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3) b(%9.2f) star(0.10 0.05 0.01) stats(N)

log close


* cubic graphs

est restore oil2_c_3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p_3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp

twoway (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("US95 intensities, oil2_c_3 and oil2_p_3")
graph export US95intensities/oil2_c_p_3.png, replace
drop US95oilCONSUMpred US95oilPRODpred



est restore oil3_c_3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp

twoway (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("US95 intensities, oil3_c_3 and oil3_p_3")
graph export US95intensities/oil3_c_p_3.png, replace


* for paper, Fig 1a
twoway (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("US95 intensities, FGLS, AR(1)")
graph export US95intensities/Figure1a.png, replace
drop US95oilCONSUMpred US95oilPRODpred




est restore energy2_c_3
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p_3
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp

twoway (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("US95 intensities, energy2_c_3 and energy2_p_3")
graph export US95intensities/energy2_c_p_3.png, replace
drop US95energyCONSUMpred US95energyPRODpred



est restore energy3_c_3
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p_3
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp

twoway (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("US95 intensities, energy3_c_3 and energy3_p_3")
graph export US95intensities/energy3_c_p_3.png, replace


* for paper, Fig 1b
twoway (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels-equivalent of energy per capita per day") legend(label(1 "Consumption"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("US95 intensities, FGLS, AR(1)")
graph export US95intensities/Figure1b.png, replace
drop US95energyCONSUMpred US95energyPRODpred



log using US95intensities/reg_output_GDP3, append
* Hypotheses tests

* Cubic

* oil

quietly reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store oil1_c
quietly reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store oil1_p

* without cluster
quietly suest oil1_c oil1_p

* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))


* with cluster
quietly suest oil1_c oil1_p, cluster(ccode)


* test slopes

test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)))



est clear
* energy

quietly reg lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store energy1_c
quietly reg lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
quietly est store energy1_p

* without cluster
quietly suest energy1_c energy1_p

* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))
* --> same peaks

* with cluster
quietly suest energy1_c energy1_p, cluster(ccode)


* test slopes

test ([energy1_c_mean]_cons = [energy1_p_mean]_cons) ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)
test ([energy1_c_mean]lnPWT_GDPplcap = [energy1_p_mean]lnPWT_GDPplcap) ([energy1_c_mean]lnPWT_GDPplcap2 = [energy1_p_mean]lnPWT_GDPplcap2) ([energy1_c_mean]lnPWT_GDPplcap3 = [energy1_p_mean]lnPWT_GDPplcap3)


* calculate peaks

nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3))
* --> use -sqrt
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
nlcom exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 + sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3))
* --> use -sqrt


* test peaks

testnl (exp((-2 * [energy1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_p_mean]lnPWT_GDPplcap * [energy1_p_mean]lnPWT_GDPplcap3)))/(6 * [energy1_p_mean]lnPWT_GDPplcap3)) = exp((-2 * [energy1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([energy1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [energy1_c_mean]lnPWT_GDPplcap * [energy1_c_mean]lnPWT_GDPplcap3)))/(6 * [energy1_c_mean]lnPWT_GDPplcap3)))

log close
est clear








****


quietly xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store oil2_c_3
quietly xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store oil2_p_3

quietly xtgls lnUSoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store USoil2_c_3
quietly xtgls lnUSoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store USoil2_p_3

quietly xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store US95oil2_c_3
quietly xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store US95oil2_p_3


est restore oil2_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

est restore USoil2_c_3
predict Cp
gen USoilCONSUMpred = exp(Cp)
drop Cp

est restore USoil2_p_3
predict Pp
gen USoilPRODpred = exp(Pp)
drop Pp

est restore US95oil2_c_3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore US95oil2_p_3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp


twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter USoilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(oh) legend(label(3 "Consumption, US intensities"))) (scatter USoilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(smplus) legend(label(4 "Production, US intensities"))) (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(5 "Consumption, 1995 US intensities"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(6 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil2_c_p.png")
graph export ALLintensities/oil2_c_p.png, replace
drop oilCONSUMpred oilPRODpred USoilCONSUMpred USoilPRODpred US95oilCONSUMpred US95oilPRODpred
est clear





quietly xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_c_3
quietly xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_p_3

quietly xtgls lnUSoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store USoil3_c_3
quietly xtgls lnUSoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store USoil3_p_3

quietly xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_c_3
quietly xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_p_3


est restore oil3_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

est restore USoil3_c_3
predict Cp
gen USoilCONSUMpred = exp(Cp)
drop Cp

est restore USoil3_p_3
predict Pp
gen USoilPRODpred = exp(Pp)
drop Pp

est restore US95oil3_c_3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore US95oil3_p_3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp


twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter USoilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(oh) legend(label(3 "Consumption, US intensities"))) (scatter USoilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(smplus) legend(label(4 "Production, US intensities"))) (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(5 "Consumption, 1995 US intensities"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(6 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil3_c_p.png")
graph export ALLintensities/oil3_c_p.png, replace
drop oilCONSUMpred oilPRODpred USoilCONSUMpred USoilPRODpred US95oilCONSUMpred US95oilPRODpred
est clear




quietly xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store energy2_c_3
quietly xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store energy2_p_3

quietly xtgls lnUSenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store USenergy2_c_3
quietly xtgls lnUSenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store USenergy2_p_3

quietly xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store US95energy2_c_3
quietly xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic)
quietly est store US95energy2_p_3


est restore energy2_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

est restore USenergy2_c_3
predict Cp
gen USenergyCONSUMpred = exp(Cp)
drop Cp

est restore USenergy2_p_3
predict Pp
gen USenergyPRODpred = exp(Pp)
drop Pp

est restore US95energy2_c_3
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore US95energy2_p_3
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp


twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter USenergyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(oh) legend(label(3 "Consumption, US intensities"))) (scatter USenergyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(smplus) legend(label(4 "Production, US intensities"))) (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(5 "Consumption, 1995 US intensities"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(6 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy2_c_p.png")
graph export ALLintensities/energy2_c_p.png, replace
drop energyCONSUMpred energyPRODpred USenergyCONSUMpred USenergyPRODpred US95energyCONSUMpred US95energyPRODpred
est clear



quietly xtgls lnenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store energy3_c_3
quietly xtgls lnenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store energy3_p_3

quietly xtgls lnUSenergyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store USenergy3_c_3
quietly xtgls lnUSenergyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store USenergy3_p_3

quietly xtgls lnUS95energyCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95energy3_c_3
quietly xtgls lnUS95energyPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95energy3_p_3


est restore energy3_c_3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_p_3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

est restore USenergy3_c_3
predict Cp
gen USenergyCONSUMpred = exp(Cp)
drop Cp

est restore USenergy3_p_3
predict Pp
gen USenergyPRODpred = exp(Pp)
drop Pp

est restore US95energy3_c_3
predict Cp
gen US95energyCONSUMpred = exp(Cp)
drop Cp

est restore US95energy3_p_3
predict Pp
gen US95energyPRODpred = exp(Pp)
drop Pp


twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter USenergyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(oh) legend(label(3 "Consumption, US intensities"))) (scatter USenergyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(smplus) legend(label(4 "Production, US intensities"))) (scatter US95energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(5 "Consumption, 1995 US intensities"))) (scatter US95energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(6 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Total Energy") subtitle("energy3_c_p.png")
graph export ALLintensities/energy3_c_p.png, replace
drop energyCONSUMpred energyPRODpred USenergyCONSUMpred USenergyPRODpred US95energyCONSUMpred US95energyPRODpred
est clear






* plot for fitted regression with OLS, no fixed effects


* cubic regression, with US intensities

reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

reg lnUSoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Cp
gen USoilCONSUMpred = exp(Cp)
drop Cp
reg lnUSoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Pp
gen USoilPRODpred = exp(Pp)
drop Pp

reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp
reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter USoilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(oh) legend(label(3 "Consumption, US intensities"))) (scatter USoilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(smplus) legend(label(4 "Production, US intensities"))) (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(5 "Consumption, 1995 US intensities"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(6 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil")
drop oilCONSUMpred oilPRODpred USoilCONSUMpred USoilPRODpred US95oilCONSUMpred US95oilPRODpred



* for paper, Figure 3


quietly xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_c_3
quietly xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_p_3

quietly xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_c_3
quietly xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_p_3


est restore oil3_c_3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p_3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

est restore US95oil3_c_3
predict Cp
gen US95oilCONSUMpred = exp(Cp)
drop Cp

est restore US95oil3_p_3
predict Pp
gen US95oilPRODpred = exp(Pp)
drop Pp


twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))) (scatter US95oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(dh) legend(label(3 "Consumption, 1995 US intensities"))) (scatter US95oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(X) legend(label(4 "Production, 1995 US intensities"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("FGLS, AR(1)")
graph export Figure3.png, replace
drop oilCONSUMpred oilPRODpred  US95oilCONSUMpred US95oilPRODpred
est clear




****

* calculate peaks

quietly xtgls lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_c_3

nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



quietly xtgls lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store oil3_p_3

nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



quietly xtgls lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_c_3
quietly xtgls lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3, i(ccode) t(year) panels(heteroskedastic) corr(psar1) force
quietly est store US95oil3_p_3



nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))




* peaks in Fig 3 --> wildly inflated error terms

quietly reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
quietly est store oil1_c
quietly reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
quietly est store oil1_p


quietly suest oil1_c oil1_p
test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
* peak test not sensible with cubic

testnl exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))







quietly reg lnUS95oilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
quietly est store oil1_c
quietly reg lnUS95oilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 _Iccode* _Iyear*
nlcom exp((-2 * _b[lnPWT_GDPplcap2] + sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
quietly est store oil1_p


quietly suest oil1_c oil1_p
test ([oil1_c_mean]_cons = [oil1_p_mean]_cons) ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
test ([oil1_c_mean]lnPWT_GDPplcap = [oil1_p_mean]lnPWT_GDPplcap) ([oil1_c_mean]lnPWT_GDPplcap2 = [oil1_p_mean]lnPWT_GDPplcap2) ([oil1_c_mean]lnPWT_GDPplcap3 = [oil1_p_mean]lnPWT_GDPplcap3)
* peak test not sensible with cubic

testnl exp((-2 * [oil1_c_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_c_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_c_mean]lnPWT_GDPplcap * [oil1_c_mean]lnPWT_GDPplcap3)))/(6 * [oil1_c_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil1_p_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil1_p_mean]lnPWT_GDPplcap2)^2 - (12 * [oil1_p_mean]lnPWT_GDPplcap * [oil1_p_mean]lnPWT_GDPplcap3)))/(6 * [oil1_p_mean]lnPWT_GDPplcap3))





**********************
* splines
**********************
* from http://data.princeton.edu/eco572/smoothing2.html


* cubic spline graphs

sum lnPWT_GDPplcap
scalar minlnPWT_GDPplcap = 6.11375
scalar maxlnPWT_GDPplcap = 10.47695

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 2 internal knots")
graph export splines/oil_k2.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 3 internal knots")
graph export splines/oil_k3.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 4 internal knots")
graph export splines/oil_k4.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 5 internal knots")
graph export splines/oil_k5.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 6 internal knots")
graph export splines/oil_k6.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 7 internal knots")
graph export splines/oil_k7.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 8 internal knots")
graph export splines/oil_k8.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 9 internal knots")
graph export splines/oil_k9.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 10 internal knots")
graph export splines/oil_k10.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 11 internal knots")
graph export splines/oil_k11.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k*, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k*, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression, 12 internal knots")
graph export splines/oil_k12.png, replace
* --> use in paper
graph export Figure4a.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear






* cubic spline graphs, without USA

sum lnPWT_GDPplcap
scalar minlnPWT_GDPplcap = 6.11375
scalar maxlnPWT_GDPplcap = 10.47695

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 2 internal knots")
graph export splines_noUSA/oil_k2.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 3 internal knots")
graph export splines_noUSA/oil_k3.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 4 internal knots")
graph export splines_noUSA/oil_k4.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 5 internal knots")
graph export splines_noUSA/oil_k5.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 6 internal knots")
graph export splines_noUSA/oil_k6.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 7 internal knots")
graph export splines_noUSA/oil_k7.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 8 internal knots")
graph export splines_noUSA/oil_k8.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 9 internal knots")
graph export splines_noUSA/oil_k9.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 10 internal knots")
graph export splines_noUSA/oil_k10.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 11 internal knots")
graph export splines_noUSA/oil_k11.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression excluding USA, 12 internal knots")
graph export splines_noUSA/oil_k12.png, replace
* --> use in paper
graph export Figure4b.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear








* cubic spline graphs, before 1995

sum lnPWT_GDPplcap
scalar minlnPWT_GDPplcap = 6.11375
scalar maxlnPWT_GDPplcap = 10.47695

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 2 internal knots")
graph export splines_before1995/oil_k2.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 3 internal knots")
graph export splines_before1995/oil_k3.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 4 internal knots")
graph export splines_before1995/oil_k4.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 5 internal knots")
graph export splines_before1995/oil_k5.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 6 internal knots")
graph export splines_before1995/oil_k6.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 7 internal knots")
graph export splines_before1995/oil_k7.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 8 internal knots")
graph export splines_before1995/oil_k8.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 9 internal knots")
graph export splines_before1995/oil_k9.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 10 internal knots")
graph export splines_before1995/oil_k10.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 11 internal knots")
graph export splines_before1995/oil_k11.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnoilCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store oil_c_k3
reg lnoilPRODbarrelscap _y3k* if year <= 1995, noconstant
est store oil_p_k3

est restore oil_c_k3
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil_p_k3
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("cubic spline regression before 1996, 12 internal knots")
graph export splines_before1995/oil_k12.png, replace
drop oilCONSUMpred oilPRODpred _y3k*
est clear



***
* energy

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 2 internal knots")
graph export splines/energy_k2.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 3 internal knots")
graph export splines/energy_k3.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 4 internal knots")
graph export splines/energy_k4.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 5 internal knots")
graph export splines/energy_k5.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 6 internal knots")
graph export splines/energy_k6.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 7 internal knots")
graph export splines/energy_k7.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 8 internal knots")
graph export splines/energy_k8.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 9 internal knots")
graph export splines/energy_k9.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 10 internal knots")
graph export splines/energy_k10.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 11 internal knots")
graph export splines/energy_k11.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k*, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k*, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression, 12 internal knots")
graph export splines/energy_k12.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear






* cubic spline graphs, without USA

sum lnPWT_GDPplcap
scalar minlnPWT_GDPplcap = 6.11375
scalar maxlnPWT_GDPplcap = 10.47695

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 2 internal knots")
graph export splines_noUSA/energy_k2.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 3 internal knots")
graph export splines_noUSA/energy_k3.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 4 internal knots")
graph export splines_noUSA/energy_k4.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 5 internal knots")
graph export splines_noUSA/energy_k5.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 6 internal knots")
graph export splines_noUSA/energy_k6.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 7 internal knots")
graph export splines_noUSA/energy_k7.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 8 internal knots")
graph export splines_noUSA/energy_k8.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 9 internal knots")
graph export splines_noUSA/energy_k9.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 10 internal knots")
graph export splines_noUSA/energy_k10.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 11 internal knots")
graph export splines_noUSA/energy_k11.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if ccode ~= 840, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if ccode ~= 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression excluding USA, 12 internal knots")
graph export splines_noUSA/energy_k12.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear








* cubic spline graphs, before 1995

sum lnPWT_GDPplcap
scalar minlnPWT_GDPplcap = 6.11375
scalar maxlnPWT_GDPplcap = 10.47695

* 2 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 3
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.4544)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 2 internal knots")
graph export splines_before1995/energy_k2.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 3 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 4
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(1.0908)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 3 internal knots")
graph export splines_before1995/energy_k3.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 4 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 5
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.87264)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 4 internal knots")
graph export splines_before1995/energy_k4.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 5 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 6
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.7272)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 5 internal knots")
graph export splines_before1995/energy_k5.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear


* 6 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 7
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.62331429)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 6 internal knots")
graph export splines_before1995/energy_k6.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 7 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 8
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.5454)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 7 internal knots")
graph export splines_before1995/energy_k7.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 8 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 9
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.4848)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 8 internal knots")
graph export splines_before1995/energy_k8.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 9 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 10
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.43632)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 9 internal knots")
graph export splines_before1995/energy_k9.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear




* 10 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 11
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.39665455)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 10 internal knots")
graph export splines_before1995/energy_k10.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 11 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 12
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.3636)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 11 internal knots")
graph export splines_before1995/energy_k11.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear



* 12 knots

scalar step = (maxlnPWT_GDPplcap - minlnPWT_GDPplcap) / 13
di step

* manually add knots:
bspline, xvar(lnPWT_GDPplcap) knots(6.11375(.33563077)10.47695) p(3) gen(_y3k)

reg lnenergyCONSUMbarrelscap _y3k* if year <= 1995, noconstant
est store energy_c_k3
reg lnenergyPRODbarrelscap _y3k* if year <= 1995, noconstant
est store energy_p_k3

est restore energy_c_k3
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy_p_k3
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("oil-equivalent barrels per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap if year <= 1995, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Energy") subtitle("cubic spline regression before 1996, 12 internal knots")
graph export splines_before1995/energy_k12.png, replace
drop energyCONSUMpred energyPRODpred _y3k*
est clear





save temp, replace





log using hetero_slopes/quadratic, replace

**********************
* heterogeneous slopes
**********************


* quadratic regressions

xi i.ccode*lnPWT_GDPplcap i.ccode*lnPWT_GDPplcap2 i.year


reg lnoilCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust
est store oil2_c

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal

* equality of peaks
* complete, with equations missing
* testnl (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_32/(2 * _IccoXlnPa32))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_36/(2 * _IccoXlnPa36))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_40/(2 * _IccoXlnPa40))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_50/(2 * _IccoXlnPa50))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_56/(2 * _IccoXlnPa56))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_68/(2 * _IccoXlnPa68))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_76/(2 * _IccoXlnPa76))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_100/(2 * _IccoXlnPa100))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_120/(2 * _IccoXlnPa120))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_124/(2 * _IccoXlnPa124))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_144/(2 * _IccoXlnPa144))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_152/(2 * _IccoXlnPa152))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_156/(2 * _IccoXlnPa156))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_158/(2 * _IccoXlnPa158))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_170/(2 * _IccoXlnPa170))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_178/(2 * _IccoXlnPa178))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_188/(2 * _IccoXlnPa188))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_192/(2 * _IccoXlnPa192))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_196/(2 * _IccoXlnPa196))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_208/(2 * _IccoXlnPa208))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_214/(2 * _IccoXlnPa214))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_218/(2 * _IccoXlnPa218))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_222/(2 * _IccoXlnPa222))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_246/(2 * _IccoXlnPa246))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_250/(2 * _IccoXlnPa250))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_266/(2 * _IccoXlnPa266))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_288/(2 * _IccoXlnPa288))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_300/(2 * _IccoXlnPa300))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_320/(2 * _IccoXlnPa320))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_340/(2 * _IccoXlnPa340))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_348/(2 * _IccoXlnPa348))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_356/(2 * _IccoXlnPa356))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_360/(2 * _IccoXlnPa360))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_364/(2 * _IccoXlnPa364))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_372/(2 * _IccoXlnPa372))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_376/(2 * _IccoXlnPa376))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_380/(2 * _IccoXlnPa380))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_384/(2 * _IccoXlnPa384))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_388/(2 * _IccoXlnPa388))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_392/(2 * _IccoXlnPa392))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_400/(2 * _IccoXlnPa400))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_404/(2 * _IccoXlnPa404))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_410/(2 * _IccoXlnPa410))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_458/(2 * _IccoXlnPa458))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_484/(2 * _IccoXlnPa484))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_504/(2 * _IccoXlnPa504))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_528/(2 * _IccoXlnPa528))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_554/(2 * _IccoXlnPa554))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_558/(2 * _IccoXlnPa558))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_566/(2 * _IccoXlnPa566))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_578/(2 * _IccoXlnPa578))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_586/(2 * _IccoXlnPa586))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_590/(2 * _IccoXlnPa590))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_604/(2 * _IccoXlnPa604))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_608/(2 * _IccoXlnPa608))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_616/(2 * _IccoXlnPa616))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_620/(2 * _IccoXlnPa620))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_642/(2 * _IccoXlnPa642))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_643/(2 * _IccoXlnPa643))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_686/(2 * _IccoXlnPa686))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_702/(2 * _IccoXlnPa702))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_705/(2 * _IccoXlnPa705))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_710/(2 * _IccoXlnPa710))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_724/(2 * _IccoXlnPa724))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_752/(2 * _IccoXlnPa752))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_756/(2 * _IccoXlnPa756))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_760/(2 * _IccoXlnPa760))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_764/(2 * _IccoXlnPa764))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_788/(2 * _IccoXlnPa788))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_792/(2 * _IccoXlnPa792))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_818/(2 * _IccoXlnPa818))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_826/(2 * _IccoXlnPa826))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_834/(2 * _IccoXlnPa834))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_840/(2 * _IccoXlnPa840))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_858/(2 * _IccoXlnPa858))) (exp(-_IccoXlnP_12/(2 * _IccoXlnPa12)) = exp(-_IccoXlnP_862/(2 * _IccoXlnPa862))) 

* clustered
reg lnoilCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal


reg lnoilPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust
est store oil2_p

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal

* clustered
reg lnoilPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal


reg lnenergyCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust
est store energy2_R_c

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal


* clustered
reg lnenergyCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal



reg lnenergyPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust
est store energy2_R_p

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal

* clustered
reg lnenergyPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal


* --> none of the slopes are equal across countries


log close

* quadratic graphs

est restore oil2_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 642 & ccode ~= 214 & ccode ~= 178 & ccode ~= 192, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil2_c and oil2_p")
graph export hetero_slopes/oil2_c_p.png, replace
drop oilCONSUMpred oilPRODpred



est restore energy2_R_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy2_R_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 642 & ccode ~= 214 & ccode ~= 178 & ccode ~= 192, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("energy2_c and energy2_p")
graph export hetero_slopes/energy2_c_p.png, replace
drop energyCONSUMpred energyPRODpred


est clear


log using hetero_slopes/cubic, replace

* cubic regressions

xi i.ccode*lnPWT_GDPplcap i.ccode*lnPWT_GDPplcap2 i.ccode*lnPWT_GDPplcap3 i.year


reg lnoilCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust
est store oil3_c

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal


* clustered
reg lnoilCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal



reg lnoilPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust
est store oil3_p

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal


* clustered
reg lnoilPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal



reg lnenergyCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust
est store energy3_R_c

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal


* clustered
reg lnenergyCONSUMbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal



reg lnenergyPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust
est store energy3_R_p

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal

* clustered
reg lnenergyPRODbarrelscap _IccoXlnP_* _IccoXlnPa* _IccoXlnPb* _Iccode* _Iyear*, noconstant robust cluster(ccode)

* equality of slopes across countries
testparm _Iccode*, equal
testparm _IccoXlnP_*, equal
testparm _IccoXlnPa*, equal
testparm _IccoXlnPb*, equal



* --> none of the slopes are equal across countries

log close

* cubic graphs

est restore oil3_c
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil3_p
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode ~= 642 & ccode ~= 214 & ccode ~= 178 & ccode ~= 192, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("oil3_c and oil3_p")
graph export hetero_slopes/oil3_c_p.png, replace
drop oilCONSUMpred oilPRODpred



est restore energy3_R_c
predict Cp
gen energyCONSUMpred = exp(Cp)
drop Cp

est restore energy3_R_p
predict Pp
gen energyPRODpred = exp(Pp)
drop Pp

twoway (scatter energyCONSUMpred PWT_GDPplcap if ccode ~= 642 & ccode ~= 214 & ccode ~= 178 & ccode ~= 192, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of energy per capita per day") legend(label(1 "Consumption"))) (scatter energyPRODpred PWT_GDPplcap, mlabel(ccode) xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("energy3_c and energy3_p")
graph export hetero_slopes/energy3_c_p.png, replace
drop energyCONSUMpred energyPRODpred


est clear





**********************
* country-specific regressions
**********************

* DOLS lags

sort ccode year
gen lnPWT_GDPplcapF1 = lnPWT_GDPplcap - F.lnPWT_GDPplcap
gen lnPWT_GDPplcapF2 = lnPWT_GDPplcap - F2.lnPWT_GDPplcap
gen lnPWT_GDPplcap2F1 = lnPWT_GDPplcap2 - F.lnPWT_GDPplcap2
gen lnPWT_GDPplcap2F2 = lnPWT_GDPplcap2 - F2.lnPWT_GDPplcap2
gen lnPWT_GDPplcap3F1 = lnPWT_GDPplcap3 - F.lnPWT_GDPplcap3
gen lnPWT_GDPplcap3F2 = lnPWT_GDPplcap3 - F2.lnPWT_GDPplcap3

* gen lnPWT_GDPplcapS1 = lnPWT_GDPplcap - L.lnPWT_GDPplcap
* gen lnPWT_GDPplcapS2 = lnPWT_GDPplcap - L2.lnPWT_GDPplcap
* gen lnPWT_GDPplcap2S1 = lnPWT_GDPplcap2 - L.lnPWT_GDPplcap2
* gen lnPWT_GDPplcap2S2 = lnPWT_GDPplcap2 - L2.lnPWT_GDPplcap2
* gen lnPWT_GDPplcap3S1 = lnPWT_GDPplcap3 - L.lnPWT_GDPplcap3
* gen lnPWT_GDPplcap3S2 = lnPWT_GDPplcap3 - L2.lnPWT_GDPplcap3


save temp1, replace




* AIC

log using bycountry/aic, replace

tsset ccode year

varsoc lnoilCONSUMbarrelscap if ccode == 12
varsoc lnoilCONSUMbarrelscap if ccode == 32
varsoc lnoilCONSUMbarrelscap if ccode == 36
varsoc lnoilCONSUMbarrelscap if ccode == 40
varsoc lnoilCONSUMbarrelscap if ccode == 50
varsoc lnoilCONSUMbarrelscap if ccode == 56
varsoc lnoilCONSUMbarrelscap if ccode == 68
varsoc lnoilCONSUMbarrelscap if ccode == 100
varsoc lnoilCONSUMbarrelscap if ccode == 120
varsoc lnoilCONSUMbarrelscap if ccode == 124
varsoc lnoilCONSUMbarrelscap if ccode == 144
varsoc lnoilCONSUMbarrelscap if ccode == 152
varsoc lnoilCONSUMbarrelscap if ccode == 156
varsoc lnoilCONSUMbarrelscap if ccode == 158
varsoc lnoilCONSUMbarrelscap if ccode == 170
varsoc lnoilCONSUMbarrelscap if ccode == 178, maxlag(3)
varsoc lnoilCONSUMbarrelscap if ccode == 188
varsoc lnoilCONSUMbarrelscap if ccode == 196
varsoc lnoilCONSUMbarrelscap if ccode == 208
varsoc lnoilCONSUMbarrelscap if ccode == 214
varsoc lnoilCONSUMbarrelscap if ccode == 218
varsoc lnoilCONSUMbarrelscap if ccode == 222
varsoc lnoilCONSUMbarrelscap if ccode == 246
varsoc lnoilCONSUMbarrelscap if ccode == 250
varsoc lnoilCONSUMbarrelscap if ccode == 288
varsoc lnoilCONSUMbarrelscap if ccode == 300
varsoc lnoilCONSUMbarrelscap if ccode == 320
varsoc lnoilCONSUMbarrelscap if ccode == 340
varsoc lnoilCONSUMbarrelscap if ccode == 348
varsoc lnoilCONSUMbarrelscap if ccode == 356
varsoc lnoilCONSUMbarrelscap if ccode == 360
varsoc lnoilCONSUMbarrelscap if ccode == 364
varsoc lnoilCONSUMbarrelscap if ccode == 372
varsoc lnoilCONSUMbarrelscap if ccode == 376
varsoc lnoilCONSUMbarrelscap if ccode == 380
varsoc lnoilCONSUMbarrelscap if ccode == 384
varsoc lnoilCONSUMbarrelscap if ccode == 388
varsoc lnoilCONSUMbarrelscap if ccode == 392
varsoc lnoilCONSUMbarrelscap if ccode == 400
varsoc lnoilCONSUMbarrelscap if ccode == 404
varsoc lnoilCONSUMbarrelscap if ccode == 410
varsoc lnoilCONSUMbarrelscap if ccode == 458
varsoc lnoilCONSUMbarrelscap if ccode == 484
varsoc lnoilCONSUMbarrelscap if ccode == 504
varsoc lnoilCONSUMbarrelscap if ccode == 528
varsoc lnoilCONSUMbarrelscap if ccode == 554
varsoc lnoilCONSUMbarrelscap if ccode == 558, maxlag(3)
varsoc lnoilCONSUMbarrelscap if ccode == 566
varsoc lnoilCONSUMbarrelscap if ccode == 578
varsoc lnoilCONSUMbarrelscap if ccode == 586
varsoc lnoilCONSUMbarrelscap if ccode == 590
varsoc lnoilCONSUMbarrelscap if ccode == 604
varsoc lnoilCONSUMbarrelscap if ccode == 608
varsoc lnoilCONSUMbarrelscap if ccode == 616
varsoc lnoilCONSUMbarrelscap if ccode == 620
varsoc lnoilCONSUMbarrelscap if ccode == 642
varsoc lnoilCONSUMbarrelscap if ccode == 643
varsoc lnoilCONSUMbarrelscap if ccode == 686
varsoc lnoilCONSUMbarrelscap if ccode == 702
varsoc lnoilCONSUMbarrelscap if ccode == 705
varsoc lnoilCONSUMbarrelscap if ccode == 710
varsoc lnoilCONSUMbarrelscap if ccode == 724
varsoc lnoilCONSUMbarrelscap if ccode == 752
varsoc lnoilCONSUMbarrelscap if ccode == 756
varsoc lnoilCONSUMbarrelscap if ccode == 760
varsoc lnoilCONSUMbarrelscap if ccode == 788
varsoc lnoilCONSUMbarrelscap if ccode == 792
varsoc lnoilCONSUMbarrelscap if ccode == 818
varsoc lnoilCONSUMbarrelscap if ccode == 826
varsoc lnoilCONSUMbarrelscap if ccode == 834
varsoc lnoilCONSUMbarrelscap if ccode == 840
varsoc lnoilCONSUMbarrelscap if ccode == 858
varsoc lnoilCONSUMbarrelscap if ccode == 862

log close




gen nURl1CONSUMp5 = 0
gen nURl1CONSUMp10 = 0
gen nURl2CONSUMp5 = 0
gen nURl2CONSUMp10 = 0
gen nURl3CONSUMp5 = 0
gen nURl3CONSUMp10 = 0
gen nURl1PRODp5 = 0
gen nURl1PRODp10 = 0
gen nURl2PRODp5 = 0
gen nURl2PRODp10 = 0
gen nURl3PRODp5 = 0
gen nURl3PRODp10 = 0
gen nURl1GDPp5 = 0
gen nURl1GDPp10 = 0
gen nURl2GDPp5 = 0
gen nURl2GDPp10 = 0
gen nURl3GDPp5 = 0
gen nURl3GDPp10 = 0
gen nURl1GDP2_p5 = 0
gen nURl1GDP2_p10 = 0
gen nURl2GDP2_p5 = 0
gen nURl2GDP2_p10 = 0
gen nURl3GDP2_p5 = 0
gen nURl3GDP2_p10 = 0
gen nURl1GDP3_p5 = 0
gen nURl1GDP3_p10 = 0
gen nURl2GDP3_p5 = 0
gen nURl2GDP3_p10 = 0
gen nURl3GDP3_p5 = 0
gen nURl3GDP3_p10 = 0
gen nURntl1CONSUMp5 = 0
gen nURntl1CONSUMp10 = 0
gen nURntl2CONSUMp5 = 0
gen nURntl2CONSUMp10 = 0
gen nURntl3CONSUMp5 = 0
gen nURntl3CONSUMp10 = 0
gen nURntl1PRODp5 = 0
gen nURntl1PRODp10 = 0
gen nURntl2PRODp5 = 0
gen nURntl2PRODp10 = 0
gen nURntl3PRODp5 = 0
gen nURntl3PRODp10 = 0
gen nURntl1GDPp5 = 0
gen nURntl1GDPp10 = 0
gen nURntl2GDPp5 = 0
gen nURntl2GDPp10 = 0
gen nURntl3GDPp5 = 0
gen nURntl3GDPp10 = 0
gen nURntl1GDP2_p5 = 0
gen nURntl1GDP2_p10 = 0
gen nURntl2GDP2_p5 = 0
gen nURntl2GDP2_p10 = 0
gen nURntl3GDP2_p5 = 0
gen nURntl3GDP2_p10 = 0
gen nURntl1GDP3_p5 = 0
gen nURntl1GDP3_p10 = 0
gen nURntl2GDP3_p5 = 0
gen nURntl2GDP3_p10 = 0
gen nURntl3GDP3_p5 = 0
gen nURntl3GDP3_p10 = 0

gen Cointl0CONSUM2_p5 = 0
gen Cointl0CONSUM2_p10 = 0
gen Cointl1CONSUM2_p5 = 0
gen Cointl1CONSUM2_p10 = 0
gen Cointl2CONSUM2_p5 = 0
gen Cointl2CONSUM2_p10 = 0
gen Cointl0PROD2_p5 = 0
gen Cointl0PROD2_p10 = 0
gen Cointl1PROD2_p5 = 0
gen Cointl1PROD2_p10 = 0
gen Cointl2PROD2_p5 = 0
gen Cointl2PROD2_p10 = 0
gen Cointl0CONSUM3_p5 = 0
gen Cointl0CONSUM3_p10 = 0
gen Cointl1CONSUM3_p5 = 0
gen Cointl1CONSUM3_p10 = 0
gen Cointl2CONSUM3_p5 = 0
gen Cointl2CONSUM3_p10 = 0
gen Cointl0PROD3_p5 = 0
gen Cointl0PROD3_p10 = 0
gen Cointl1PROD3_p5 = 0
gen Cointl1PROD3_p10 = 0
gen Cointl2PROD3_p5 = 0
gen Cointl2PROD3_p10 = 0
gen Cointntl0CONSUM2_p5 = 0
gen Cointntl0CONSUM2_p10 = 0
gen Cointntl1CONSUM2_p5 = 0
gen Cointntl1CONSUM2_p10 = 0
gen Cointntl2CONSUM2_p5 = 0
gen Cointntl2CONSUM2_p10 = 0
gen Cointntl0PROD2_p5 = 0
gen Cointntl0PROD2_p10 = 0
gen Cointntl1PROD2_p5 = 0
gen Cointntl1PROD2_p10 = 0
gen Cointntl2PROD2_p5 = 0
gen Cointntl2PROD2_p10 = 0
gen Cointntl0CONSUM3_p5 = 0
gen Cointntl0CONSUM3_p10 = 0
gen Cointntl1CONSUM3_p5 = 0
gen Cointntl1CONSUM3_p10 = 0
gen Cointntl2CONSUM3_p5 = 0
gen Cointntl2CONSUM3_p10 = 0
gen Cointntl0PROD3_p5 = 0
gen Cointntl0PROD3_p10 = 0
gen Cointntl1PROD3_p5 = 0
gen Cointntl1PROD3_p10 = 0
gen Cointntl2PROD3_p5 = 0
gen Cointntl2PROD3_p10 = 0

log using bycountry/dfullerlog, replace


****
* ccode == 12
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 12, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilCONSUMbarrelscap if ccode == 12, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilCONSUMbarrelscap if ccode == 12, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 12, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilCONSUMbarrelscap if ccode == 12, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilCONSUMbarrelscap if ccode == 12, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnoilPRODbarrelscap if ccode == 12, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap if ccode == 12, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap2 if ccode == 12, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller lnPWT_GDPplcap3 if ccode == 12, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 12


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 12, title("CONSUMResiduals vs year") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear12CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 12, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged12CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 12, title("PRODResiduals vs year") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear12PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 12, title("PRODResiduals vs lagged residuals") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged12PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 12, title("Residuals vs year") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear12CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 12, title("Residuals vs lagged residuals") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged12CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 12, title("Residuals vs year") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear12PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 12, title("Residuals vs lagged residuals") subtitle("ccode == 12") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged12PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 12, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2CONSUM if ccode == 12, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2CONSUM if ccode == 12, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12

* with intercept but no trend

dfuller res2CONSUM if ccode == 12, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2CONSUM if ccode == 12, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2CONSUM if ccode == 12, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res2PROD if ccode == 12, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3CONSUM if ccode == 12, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12
dfuller res3PROD if ccode == 12, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 12
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 12


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 32
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 32, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilCONSUMbarrelscap if ccode == 32, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilCONSUMbarrelscap if ccode == 32, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 32, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilCONSUMbarrelscap if ccode == 32, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilCONSUMbarrelscap if ccode == 32, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnoilPRODbarrelscap if ccode == 32, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap if ccode == 32, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap2 if ccode == 32, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller lnPWT_GDPplcap3 if ccode == 32, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 32


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 32, title("CONSUMResiduals vs year") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear32CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 32, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged32CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 32, title("PRODResiduals vs year") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear32PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 32, title("PRODResiduals vs lagged residuals") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged32PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 32, title("Residuals vs year") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear32CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 32, title("Residuals vs lagged residuals") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged32CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 32, title("Residuals vs year") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear32PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 32, title("Residuals vs lagged residuals") subtitle("ccode == 32") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged32PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 32, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2CONSUM if ccode == 32, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2CONSUM if ccode == 32, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32

* with intercept but no trend

dfuller res2CONSUM if ccode == 32, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2CONSUM if ccode == 32, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2CONSUM if ccode == 32, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res2PROD if ccode == 32, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3CONSUM if ccode == 32, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32
dfuller res3PROD if ccode == 32, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 32
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 32


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 36
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 36, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilCONSUMbarrelscap if ccode == 36, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilCONSUMbarrelscap if ccode == 36, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 36, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilCONSUMbarrelscap if ccode == 36, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilCONSUMbarrelscap if ccode == 36, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnoilPRODbarrelscap if ccode == 36, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap if ccode == 36, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap2 if ccode == 36, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller lnPWT_GDPplcap3 if ccode == 36, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 36


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 36, title("CONSUMResiduals vs year") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear36CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 36, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged36CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 36, title("PRODResiduals vs year") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear36PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 36, title("PRODResiduals vs lagged residuals") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged36PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 36, title("Residuals vs year") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear36CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 36, title("Residuals vs lagged residuals") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged36CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 36, title("Residuals vs year") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear36PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 36, title("Residuals vs lagged residuals") subtitle("ccode == 36") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged36PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 36, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2CONSUM if ccode == 36, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2CONSUM if ccode == 36, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36

* with intercept but no trend

dfuller res2CONSUM if ccode == 36, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2CONSUM if ccode == 36, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2CONSUM if ccode == 36, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res2PROD if ccode == 36, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3CONSUM if ccode == 36, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36
dfuller res3PROD if ccode == 36, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 36
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 36


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 40
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 40, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilCONSUMbarrelscap if ccode == 40, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilCONSUMbarrelscap if ccode == 40, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 40, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilCONSUMbarrelscap if ccode == 40, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilCONSUMbarrelscap if ccode == 40, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnoilPRODbarrelscap if ccode == 40, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap if ccode == 40, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap2 if ccode == 40, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller lnPWT_GDPplcap3 if ccode == 40, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 40


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 40, title("CONSUMResiduals vs year") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear40CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 40, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged40CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 40, title("PRODResiduals vs year") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear40PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 40, title("PRODResiduals vs lagged residuals") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged40PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 40, title("Residuals vs year") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear40CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 40, title("Residuals vs lagged residuals") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged40CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 40, title("Residuals vs year") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear40PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 40, title("Residuals vs lagged residuals") subtitle("ccode == 40") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged40PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 40, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2CONSUM if ccode == 40, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2CONSUM if ccode == 40, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40

* with intercept but no trend

dfuller res2CONSUM if ccode == 40, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2CONSUM if ccode == 40, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2CONSUM if ccode == 40, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res2PROD if ccode == 40, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3CONSUM if ccode == 40, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40
dfuller res3PROD if ccode == 40, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 40
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 40


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 50
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 50, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilCONSUMbarrelscap if ccode == 50, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilCONSUMbarrelscap if ccode == 50, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 50, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilCONSUMbarrelscap if ccode == 50, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilCONSUMbarrelscap if ccode == 50, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnoilPRODbarrelscap if ccode == 50, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap if ccode == 50, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap2 if ccode == 50, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller lnPWT_GDPplcap3 if ccode == 50, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 50


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 50, title("CONSUMResiduals vs year") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear50CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 50, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged50CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 50, title("PRODResiduals vs year") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear50PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 50, title("PRODResiduals vs lagged residuals") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged50PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 50, title("Residuals vs year") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear50CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 50, title("Residuals vs lagged residuals") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged50CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 50, title("Residuals vs year") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear50PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 50, title("Residuals vs lagged residuals") subtitle("ccode == 50") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged50PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 50, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2CONSUM if ccode == 50, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2CONSUM if ccode == 50, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50

* with intercept but no trend

dfuller res2CONSUM if ccode == 50, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2CONSUM if ccode == 50, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2CONSUM if ccode == 50, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res2PROD if ccode == 50, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3CONSUM if ccode == 50, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50
dfuller res3PROD if ccode == 50, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 50
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 50


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 56
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 56, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilCONSUMbarrelscap if ccode == 56, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilCONSUMbarrelscap if ccode == 56, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 56, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilCONSUMbarrelscap if ccode == 56, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilCONSUMbarrelscap if ccode == 56, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnoilPRODbarrelscap if ccode == 56, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap if ccode == 56, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap2 if ccode == 56, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller lnPWT_GDPplcap3 if ccode == 56, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 56


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 56, title("CONSUMResiduals vs year") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear56CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 56, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged56CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 56, title("PRODResiduals vs year") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear56PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 56, title("PRODResiduals vs lagged residuals") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged56PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 56, title("Residuals vs year") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear56CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 56, title("Residuals vs lagged residuals") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged56CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 56, title("Residuals vs year") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear56PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 56, title("Residuals vs lagged residuals") subtitle("ccode == 56") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged56PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 56, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2CONSUM if ccode == 56, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2CONSUM if ccode == 56, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56

* with intercept but no trend

dfuller res2CONSUM if ccode == 56, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2CONSUM if ccode == 56, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2CONSUM if ccode == 56, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res2PROD if ccode == 56, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3CONSUM if ccode == 56, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56
dfuller res3PROD if ccode == 56, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 56
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 56


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 68
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 68, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilCONSUMbarrelscap if ccode == 68, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilCONSUMbarrelscap if ccode == 68, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 68, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilCONSUMbarrelscap if ccode == 68, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilCONSUMbarrelscap if ccode == 68, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnoilPRODbarrelscap if ccode == 68, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap if ccode == 68, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap2 if ccode == 68, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller lnPWT_GDPplcap3 if ccode == 68, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 68


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 68, title("CONSUMResiduals vs year") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear68CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 68, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged68CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 68, title("PRODResiduals vs year") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear68PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 68, title("PRODResiduals vs lagged residuals") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged68PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 68, title("Residuals vs year") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear68CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 68, title("Residuals vs lagged residuals") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged68CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 68, title("Residuals vs year") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear68PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 68, title("Residuals vs lagged residuals") subtitle("ccode == 68") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged68PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 68, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2CONSUM if ccode == 68, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2CONSUM if ccode == 68, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68

* with intercept but no trend

dfuller res2CONSUM if ccode == 68, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2CONSUM if ccode == 68, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2CONSUM if ccode == 68, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res2PROD if ccode == 68, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3CONSUM if ccode == 68, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68
dfuller res3PROD if ccode == 68, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 68
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 68


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 100
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 100, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilCONSUMbarrelscap if ccode == 100, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilCONSUMbarrelscap if ccode == 100, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 100, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilCONSUMbarrelscap if ccode == 100, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilCONSUMbarrelscap if ccode == 100, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnoilPRODbarrelscap if ccode == 100, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap if ccode == 100, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap2 if ccode == 100, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller lnPWT_GDPplcap3 if ccode == 100, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 100


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 100, title("CONSUMResiduals vs year") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear100CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 100, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged100CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 100, title("PRODResiduals vs year") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear100PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 100, title("PRODResiduals vs lagged residuals") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged100PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 100, title("Residuals vs year") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear100CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 100, title("Residuals vs lagged residuals") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged100CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 100, title("Residuals vs year") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear100PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 100, title("Residuals vs lagged residuals") subtitle("ccode == 100") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged100PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 100, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2CONSUM if ccode == 100, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2CONSUM if ccode == 100, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100

* with intercept but no trend

dfuller res2CONSUM if ccode == 100, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2CONSUM if ccode == 100, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2CONSUM if ccode == 100, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res2PROD if ccode == 100, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3CONSUM if ccode == 100, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100
dfuller res3PROD if ccode == 100, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 100
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 100


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 120
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 120, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilCONSUMbarrelscap if ccode == 120, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilCONSUMbarrelscap if ccode == 120, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 120, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilCONSUMbarrelscap if ccode == 120, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilCONSUMbarrelscap if ccode == 120, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnoilPRODbarrelscap if ccode == 120, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap if ccode == 120, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap2 if ccode == 120, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller lnPWT_GDPplcap3 if ccode == 120, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 120


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 120, title("CONSUMResiduals vs year") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear120CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 120, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged120CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 120, title("PRODResiduals vs year") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear120PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 120, title("PRODResiduals vs lagged residuals") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged120PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 120, title("Residuals vs year") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear120CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 120, title("Residuals vs lagged residuals") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged120CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 120, title("Residuals vs year") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear120PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 120, title("Residuals vs lagged residuals") subtitle("ccode == 120") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged120PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 120, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2CONSUM if ccode == 120, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2CONSUM if ccode == 120, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120

* with intercept but no trend

dfuller res2CONSUM if ccode == 120, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2CONSUM if ccode == 120, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2CONSUM if ccode == 120, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res2PROD if ccode == 120, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3CONSUM if ccode == 120, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120
dfuller res3PROD if ccode == 120, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 120
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 120


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 124
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 124, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilCONSUMbarrelscap if ccode == 124, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilCONSUMbarrelscap if ccode == 124, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 124, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilCONSUMbarrelscap if ccode == 124, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilCONSUMbarrelscap if ccode == 124, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnoilPRODbarrelscap if ccode == 124, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap if ccode == 124, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap2 if ccode == 124, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller lnPWT_GDPplcap3 if ccode == 124, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 124


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 124, title("CONSUMResiduals vs year") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear124CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 124, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged124CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 124, title("PRODResiduals vs year") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear124PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 124, title("PRODResiduals vs lagged residuals") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged124PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 124, title("Residuals vs year") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear124CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 124, title("Residuals vs lagged residuals") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged124CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 124, title("Residuals vs year") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear124PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 124, title("Residuals vs lagged residuals") subtitle("ccode == 124") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged124PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 124, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2CONSUM if ccode == 124, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2CONSUM if ccode == 124, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124

* with intercept but no trend

dfuller res2CONSUM if ccode == 124, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2CONSUM if ccode == 124, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2CONSUM if ccode == 124, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res2PROD if ccode == 124, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3CONSUM if ccode == 124, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124
dfuller res3PROD if ccode == 124, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 124
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 124


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 144
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 144, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilCONSUMbarrelscap if ccode == 144, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilCONSUMbarrelscap if ccode == 144, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 144, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilCONSUMbarrelscap if ccode == 144, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilCONSUMbarrelscap if ccode == 144, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnoilPRODbarrelscap if ccode == 144, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap if ccode == 144, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap2 if ccode == 144, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller lnPWT_GDPplcap3 if ccode == 144, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 144


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 144, title("CONSUMResiduals vs year") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear144CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 144, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged144CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 144, title("PRODResiduals vs year") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear144PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 144, title("PRODResiduals vs lagged residuals") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged144PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 144, title("Residuals vs year") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear144CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 144, title("Residuals vs lagged residuals") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged144CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 144, title("Residuals vs year") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear144PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 144, title("Residuals vs lagged residuals") subtitle("ccode == 144") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged144PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 144, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2CONSUM if ccode == 144, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2CONSUM if ccode == 144, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144

* with intercept but no trend

dfuller res2CONSUM if ccode == 144, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2CONSUM if ccode == 144, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2CONSUM if ccode == 144, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res2PROD if ccode == 144, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3CONSUM if ccode == 144, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144
dfuller res3PROD if ccode == 144, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 144
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 144


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 152
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 152, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilCONSUMbarrelscap if ccode == 152, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilCONSUMbarrelscap if ccode == 152, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 152, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilCONSUMbarrelscap if ccode == 152, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilCONSUMbarrelscap if ccode == 152, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnoilPRODbarrelscap if ccode == 152, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap if ccode == 152, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap2 if ccode == 152, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller lnPWT_GDPplcap3 if ccode == 152, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 152


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 152, title("CONSUMResiduals vs year") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear152CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 152, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged152CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 152, title("PRODResiduals vs year") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear152PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 152, title("PRODResiduals vs lagged residuals") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged152PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 152, title("Residuals vs year") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear152CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 152, title("Residuals vs lagged residuals") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged152CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 152, title("Residuals vs year") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear152PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 152, title("Residuals vs lagged residuals") subtitle("ccode == 152") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged152PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 152, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2CONSUM if ccode == 152, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2CONSUM if ccode == 152, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152

* with intercept but no trend

dfuller res2CONSUM if ccode == 152, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2CONSUM if ccode == 152, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2CONSUM if ccode == 152, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res2PROD if ccode == 152, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3CONSUM if ccode == 152, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152
dfuller res3PROD if ccode == 152, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 152
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 152


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 156
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 156, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilCONSUMbarrelscap if ccode == 156, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilCONSUMbarrelscap if ccode == 156, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 156, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilCONSUMbarrelscap if ccode == 156, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilCONSUMbarrelscap if ccode == 156, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnoilPRODbarrelscap if ccode == 156, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap if ccode == 156, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap2 if ccode == 156, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller lnPWT_GDPplcap3 if ccode == 156, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 156


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 156, title("CONSUMResiduals vs year") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear156CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 156, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged156CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 156, title("PRODResiduals vs year") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear156PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 156, title("PRODResiduals vs lagged residuals") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged156PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 156, title("Residuals vs year") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear156CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 156, title("Residuals vs lagged residuals") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged156CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 156, title("Residuals vs year") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear156PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 156, title("Residuals vs lagged residuals") subtitle("ccode == 156") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged156PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 156, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2CONSUM if ccode == 156, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2CONSUM if ccode == 156, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156

* with intercept but no trend

dfuller res2CONSUM if ccode == 156, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2CONSUM if ccode == 156, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2CONSUM if ccode == 156, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res2PROD if ccode == 156, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3CONSUM if ccode == 156, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156
dfuller res3PROD if ccode == 156, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 156
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 156


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 158
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 158, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilCONSUMbarrelscap if ccode == 158, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilCONSUMbarrelscap if ccode == 158, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 158, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilCONSUMbarrelscap if ccode == 158, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilCONSUMbarrelscap if ccode == 158, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnoilPRODbarrelscap if ccode == 158, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap if ccode == 158, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap2 if ccode == 158, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller lnPWT_GDPplcap3 if ccode == 158, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 158


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 158, title("CONSUMResiduals vs year") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear158CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 158, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged158CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 158, title("PRODResiduals vs year") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear158PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 158, title("PRODResiduals vs lagged residuals") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged158PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 158, title("Residuals vs year") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear158CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 158, title("Residuals vs lagged residuals") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged158CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 158, title("Residuals vs year") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear158PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 158, title("Residuals vs lagged residuals") subtitle("ccode == 158") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged158PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 158, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2CONSUM if ccode == 158, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2CONSUM if ccode == 158, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158

* with intercept but no trend

dfuller res2CONSUM if ccode == 158, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2CONSUM if ccode == 158, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2CONSUM if ccode == 158, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res2PROD if ccode == 158, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3CONSUM if ccode == 158, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158
dfuller res3PROD if ccode == 158, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 158
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 158


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 170
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 170, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilCONSUMbarrelscap if ccode == 170, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilCONSUMbarrelscap if ccode == 170, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 170, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilCONSUMbarrelscap if ccode == 170, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilCONSUMbarrelscap if ccode == 170, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnoilPRODbarrelscap if ccode == 170, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap if ccode == 170, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap2 if ccode == 170, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller lnPWT_GDPplcap3 if ccode == 170, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 170


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 170, title("CONSUMResiduals vs year") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear170CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 170, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged170CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 170, title("PRODResiduals vs year") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear170PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 170, title("PRODResiduals vs lagged residuals") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged170PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 170, title("Residuals vs year") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear170CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 170, title("Residuals vs lagged residuals") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged170CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 170, title("Residuals vs year") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear170PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 170, title("Residuals vs lagged residuals") subtitle("ccode == 170") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged170PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 170, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2CONSUM if ccode == 170, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2CONSUM if ccode == 170, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170

* with intercept but no trend

dfuller res2CONSUM if ccode == 170, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2CONSUM if ccode == 170, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2CONSUM if ccode == 170, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res2PROD if ccode == 170, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3CONSUM if ccode == 170, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170
dfuller res3PROD if ccode == 170, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 170
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 170


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 178
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 178, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilCONSUMbarrelscap if ccode == 178, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilCONSUMbarrelscap if ccode == 178, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 178, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilCONSUMbarrelscap if ccode == 178, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilCONSUMbarrelscap if ccode == 178, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnoilPRODbarrelscap if ccode == 178, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap if ccode == 178, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap2 if ccode == 178, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller lnPWT_GDPplcap3 if ccode == 178, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 178


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 178, title("CONSUMResiduals vs year") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear178CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 178, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged178CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 178, title("PRODResiduals vs year") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear178PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 178, title("PRODResiduals vs lagged residuals") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged178PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 178, title("Residuals vs year") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear178CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 178, title("Residuals vs lagged residuals") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged178CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 178, title("Residuals vs year") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear178PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 178, title("Residuals vs lagged residuals") subtitle("ccode == 178") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged178PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 178, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2CONSUM if ccode == 178, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2CONSUM if ccode == 178, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178

* with intercept but no trend

dfuller res2CONSUM if ccode == 178, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2CONSUM if ccode == 178, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2CONSUM if ccode == 178, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res2PROD if ccode == 178, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3CONSUM if ccode == 178, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178
dfuller res3PROD if ccode == 178, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 178
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 178


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 188
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 188, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilCONSUMbarrelscap if ccode == 188, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilCONSUMbarrelscap if ccode == 188, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 188, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilCONSUMbarrelscap if ccode == 188, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilCONSUMbarrelscap if ccode == 188, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnoilPRODbarrelscap if ccode == 188, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap if ccode == 188, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap2 if ccode == 188, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller lnPWT_GDPplcap3 if ccode == 188, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 188


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 188, title("CONSUMResiduals vs year") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear188CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 188, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged188CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 188, title("PRODResiduals vs year") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear188PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 188, title("PRODResiduals vs lagged residuals") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged188PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 188, title("Residuals vs year") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear188CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 188, title("Residuals vs lagged residuals") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged188CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 188, title("Residuals vs year") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear188PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 188, title("Residuals vs lagged residuals") subtitle("ccode == 188") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged188PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 188, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2CONSUM if ccode == 188, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2CONSUM if ccode == 188, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188

* with intercept but no trend

dfuller res2CONSUM if ccode == 188, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2CONSUM if ccode == 188, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2CONSUM if ccode == 188, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res2PROD if ccode == 188, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3CONSUM if ccode == 188, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188
dfuller res3PROD if ccode == 188, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 188
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 188


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 196
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 196, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilCONSUMbarrelscap if ccode == 196, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilCONSUMbarrelscap if ccode == 196, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 196, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilCONSUMbarrelscap if ccode == 196, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilCONSUMbarrelscap if ccode == 196, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnoilPRODbarrelscap if ccode == 196, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap if ccode == 196, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap2 if ccode == 196, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller lnPWT_GDPplcap3 if ccode == 196, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 196


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 196, title("CONSUMResiduals vs year") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear196CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 196, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged196CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 196, title("PRODResiduals vs year") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear196PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 196, title("PRODResiduals vs lagged residuals") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged196PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 196, title("Residuals vs year") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear196CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 196, title("Residuals vs lagged residuals") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged196CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 196, title("Residuals vs year") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear196PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 196, title("Residuals vs lagged residuals") subtitle("ccode == 196") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged196PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 196, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2CONSUM if ccode == 196, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2CONSUM if ccode == 196, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196

* with intercept but no trend

dfuller res2CONSUM if ccode == 196, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2CONSUM if ccode == 196, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2CONSUM if ccode == 196, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res2PROD if ccode == 196, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3CONSUM if ccode == 196, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196
dfuller res3PROD if ccode == 196, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 196
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 196


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 208
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 208, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilCONSUMbarrelscap if ccode == 208, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilCONSUMbarrelscap if ccode == 208, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 208, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilCONSUMbarrelscap if ccode == 208, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilCONSUMbarrelscap if ccode == 208, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnoilPRODbarrelscap if ccode == 208, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap if ccode == 208, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap2 if ccode == 208, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller lnPWT_GDPplcap3 if ccode == 208, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 208


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 208, title("CONSUMResiduals vs year") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear208CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 208, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged208CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 208, title("PRODResiduals vs year") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear208PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 208, title("PRODResiduals vs lagged residuals") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged208PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 208, title("Residuals vs year") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear208CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 208, title("Residuals vs lagged residuals") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged208CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 208, title("Residuals vs year") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear208PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 208, title("Residuals vs lagged residuals") subtitle("ccode == 208") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged208PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 208, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2CONSUM if ccode == 208, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2CONSUM if ccode == 208, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208

* with intercept but no trend

dfuller res2CONSUM if ccode == 208, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2CONSUM if ccode == 208, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2CONSUM if ccode == 208, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res2PROD if ccode == 208, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3CONSUM if ccode == 208, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208
dfuller res3PROD if ccode == 208, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 208
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 208


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 214
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 214, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilCONSUMbarrelscap if ccode == 214, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilCONSUMbarrelscap if ccode == 214, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 214, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilCONSUMbarrelscap if ccode == 214, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilCONSUMbarrelscap if ccode == 214, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnoilPRODbarrelscap if ccode == 214, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap if ccode == 214, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap2 if ccode == 214, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller lnPWT_GDPplcap3 if ccode == 214, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 214


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 214, title("CONSUMResiduals vs year") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear214CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 214, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged214CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 214, title("PRODResiduals vs year") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear214PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 214, title("PRODResiduals vs lagged residuals") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged214PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 214, title("Residuals vs year") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear214CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 214, title("Residuals vs lagged residuals") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged214CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 214, title("Residuals vs year") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear214PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 214, title("Residuals vs lagged residuals") subtitle("ccode == 214") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged214PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 214, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2CONSUM if ccode == 214, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2CONSUM if ccode == 214, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214

* with intercept but no trend

dfuller res2CONSUM if ccode == 214, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2CONSUM if ccode == 214, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2CONSUM if ccode == 214, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res2PROD if ccode == 214, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3CONSUM if ccode == 214, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214
dfuller res3PROD if ccode == 214, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 214
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 214


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 218
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 218, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilCONSUMbarrelscap if ccode == 218, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilCONSUMbarrelscap if ccode == 218, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 218, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilCONSUMbarrelscap if ccode == 218, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilCONSUMbarrelscap if ccode == 218, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnoilPRODbarrelscap if ccode == 218, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap if ccode == 218, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap2 if ccode == 218, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller lnPWT_GDPplcap3 if ccode == 218, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 218


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 218, title("CONSUMResiduals vs year") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear218CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 218, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged218CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 218, title("PRODResiduals vs year") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear218PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 218, title("PRODResiduals vs lagged residuals") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged218PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 218, title("Residuals vs year") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear218CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 218, title("Residuals vs lagged residuals") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged218CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 218, title("Residuals vs year") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear218PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 218, title("Residuals vs lagged residuals") subtitle("ccode == 218") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged218PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 218, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2CONSUM if ccode == 218, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2CONSUM if ccode == 218, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218

* with intercept but no trend

dfuller res2CONSUM if ccode == 218, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2CONSUM if ccode == 218, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2CONSUM if ccode == 218, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res2PROD if ccode == 218, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3CONSUM if ccode == 218, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218
dfuller res3PROD if ccode == 218, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 218
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 218


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 222
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 222, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilCONSUMbarrelscap if ccode == 222, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilCONSUMbarrelscap if ccode == 222, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 222, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilCONSUMbarrelscap if ccode == 222, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilCONSUMbarrelscap if ccode == 222, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnoilPRODbarrelscap if ccode == 222, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap if ccode == 222, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap2 if ccode == 222, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller lnPWT_GDPplcap3 if ccode == 222, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 222


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 222, title("CONSUMResiduals vs year") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear222CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 222, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged222CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 222, title("PRODResiduals vs year") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear222PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 222, title("PRODResiduals vs lagged residuals") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged222PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 222, title("Residuals vs year") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear222CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 222, title("Residuals vs lagged residuals") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged222CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 222, title("Residuals vs year") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear222PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 222, title("Residuals vs lagged residuals") subtitle("ccode == 222") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged222PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 222, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2CONSUM if ccode == 222, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2CONSUM if ccode == 222, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222

* with intercept but no trend

dfuller res2CONSUM if ccode == 222, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2CONSUM if ccode == 222, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2CONSUM if ccode == 222, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res2PROD if ccode == 222, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3CONSUM if ccode == 222, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222
dfuller res3PROD if ccode == 222, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 222
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 222


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 246
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 246, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilCONSUMbarrelscap if ccode == 246, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilCONSUMbarrelscap if ccode == 246, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 246, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilCONSUMbarrelscap if ccode == 246, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilCONSUMbarrelscap if ccode == 246, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnoilPRODbarrelscap if ccode == 246, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap if ccode == 246, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap2 if ccode == 246, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller lnPWT_GDPplcap3 if ccode == 246, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 246


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 246, title("CONSUMResiduals vs year") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear246CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 246, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged246CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 246, title("PRODResiduals vs year") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear246PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 246, title("PRODResiduals vs lagged residuals") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged246PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 246, title("Residuals vs year") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear246CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 246, title("Residuals vs lagged residuals") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged246CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 246, title("Residuals vs year") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear246PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 246, title("Residuals vs lagged residuals") subtitle("ccode == 246") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged246PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 246, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2CONSUM if ccode == 246, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2CONSUM if ccode == 246, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246

* with intercept but no trend

dfuller res2CONSUM if ccode == 246, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2CONSUM if ccode == 246, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2CONSUM if ccode == 246, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res2PROD if ccode == 246, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3CONSUM if ccode == 246, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246
dfuller res3PROD if ccode == 246, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 246
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 246


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 250
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 250, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilCONSUMbarrelscap if ccode == 250, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilCONSUMbarrelscap if ccode == 250, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 250, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilCONSUMbarrelscap if ccode == 250, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilCONSUMbarrelscap if ccode == 250, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnoilPRODbarrelscap if ccode == 250, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap if ccode == 250, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap2 if ccode == 250, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller lnPWT_GDPplcap3 if ccode == 250, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 250


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 250, title("CONSUMResiduals vs year") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear250CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 250, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged250CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 250, title("PRODResiduals vs year") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear250PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 250, title("PRODResiduals vs lagged residuals") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged250PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 250, title("Residuals vs year") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear250CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 250, title("Residuals vs lagged residuals") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged250CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 250, title("Residuals vs year") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear250PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 250, title("Residuals vs lagged residuals") subtitle("ccode == 250") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged250PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 250, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2CONSUM if ccode == 250, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2CONSUM if ccode == 250, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250

* with intercept but no trend

dfuller res2CONSUM if ccode == 250, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2CONSUM if ccode == 250, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2CONSUM if ccode == 250, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res2PROD if ccode == 250, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3CONSUM if ccode == 250, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250
dfuller res3PROD if ccode == 250, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 250
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 250


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 288
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 288, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilCONSUMbarrelscap if ccode == 288, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilCONSUMbarrelscap if ccode == 288, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 288, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilCONSUMbarrelscap if ccode == 288, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilCONSUMbarrelscap if ccode == 288, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnoilPRODbarrelscap if ccode == 288, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap if ccode == 288, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap2 if ccode == 288, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller lnPWT_GDPplcap3 if ccode == 288, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 288


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 288, title("CONSUMResiduals vs year") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear288CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 288, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged288CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 288, title("PRODResiduals vs year") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear288PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 288, title("PRODResiduals vs lagged residuals") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged288PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 288, title("Residuals vs year") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear288CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 288, title("Residuals vs lagged residuals") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged288CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 288, title("Residuals vs year") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear288PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 288, title("Residuals vs lagged residuals") subtitle("ccode == 288") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged288PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 288, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2CONSUM if ccode == 288, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2CONSUM if ccode == 288, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288

* with intercept but no trend

dfuller res2CONSUM if ccode == 288, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2CONSUM if ccode == 288, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2CONSUM if ccode == 288, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res2PROD if ccode == 288, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3CONSUM if ccode == 288, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288
dfuller res3PROD if ccode == 288, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 288
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 288


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 300
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 300, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilCONSUMbarrelscap if ccode == 300, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilCONSUMbarrelscap if ccode == 300, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 300, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilCONSUMbarrelscap if ccode == 300, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilCONSUMbarrelscap if ccode == 300, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnoilPRODbarrelscap if ccode == 300, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap if ccode == 300, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap2 if ccode == 300, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller lnPWT_GDPplcap3 if ccode == 300, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 300


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 300, title("CONSUMResiduals vs year") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear300CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 300, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged300CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 300, title("PRODResiduals vs year") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear300PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 300, title("PRODResiduals vs lagged residuals") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged300PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 300, title("Residuals vs year") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear300CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 300, title("Residuals vs lagged residuals") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged300CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 300, title("Residuals vs year") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear300PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 300, title("Residuals vs lagged residuals") subtitle("ccode == 300") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged300PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 300, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2CONSUM if ccode == 300, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2CONSUM if ccode == 300, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300

* with intercept but no trend

dfuller res2CONSUM if ccode == 300, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2CONSUM if ccode == 300, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2CONSUM if ccode == 300, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res2PROD if ccode == 300, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3CONSUM if ccode == 300, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300
dfuller res3PROD if ccode == 300, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 300
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 300


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 320
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 320, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilCONSUMbarrelscap if ccode == 320, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilCONSUMbarrelscap if ccode == 320, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 320, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilCONSUMbarrelscap if ccode == 320, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilCONSUMbarrelscap if ccode == 320, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnoilPRODbarrelscap if ccode == 320, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap if ccode == 320, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap2 if ccode == 320, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller lnPWT_GDPplcap3 if ccode == 320, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 320


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 320, title("CONSUMResiduals vs year") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear320CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 320, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged320CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 320, title("PRODResiduals vs year") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear320PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 320, title("PRODResiduals vs lagged residuals") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged320PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 320, title("Residuals vs year") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear320CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 320, title("Residuals vs lagged residuals") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged320CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 320, title("Residuals vs year") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear320PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 320, title("Residuals vs lagged residuals") subtitle("ccode == 320") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged320PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 320, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2CONSUM if ccode == 320, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2CONSUM if ccode == 320, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320

* with intercept but no trend

dfuller res2CONSUM if ccode == 320, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2CONSUM if ccode == 320, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2CONSUM if ccode == 320, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res2PROD if ccode == 320, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3CONSUM if ccode == 320, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320
dfuller res3PROD if ccode == 320, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 320
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 320


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 340
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 340, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilCONSUMbarrelscap if ccode == 340, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilCONSUMbarrelscap if ccode == 340, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 340, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilCONSUMbarrelscap if ccode == 340, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilCONSUMbarrelscap if ccode == 340, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnoilPRODbarrelscap if ccode == 340, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap if ccode == 340, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap2 if ccode == 340, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller lnPWT_GDPplcap3 if ccode == 340, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 340


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 340, title("CONSUMResiduals vs year") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear340CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 340, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged340CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 340, title("PRODResiduals vs year") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear340PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 340, title("PRODResiduals vs lagged residuals") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged340PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 340, title("Residuals vs year") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear340CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 340, title("Residuals vs lagged residuals") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged340CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 340, title("Residuals vs year") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear340PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 340, title("Residuals vs lagged residuals") subtitle("ccode == 340") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged340PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 340, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2CONSUM if ccode == 340, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2CONSUM if ccode == 340, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340

* with intercept but no trend

dfuller res2CONSUM if ccode == 340, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2CONSUM if ccode == 340, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2CONSUM if ccode == 340, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res2PROD if ccode == 340, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3CONSUM if ccode == 340, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340
dfuller res3PROD if ccode == 340, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 340
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 340


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 348
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 348, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilCONSUMbarrelscap if ccode == 348, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilCONSUMbarrelscap if ccode == 348, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 348, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilCONSUMbarrelscap if ccode == 348, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilCONSUMbarrelscap if ccode == 348, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnoilPRODbarrelscap if ccode == 348, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap if ccode == 348, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap2 if ccode == 348, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller lnPWT_GDPplcap3 if ccode == 348, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 348


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 348, title("CONSUMResiduals vs year") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear348CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 348, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged348CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 348, title("PRODResiduals vs year") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear348PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 348, title("PRODResiduals vs lagged residuals") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged348PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 348, title("Residuals vs year") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear348CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 348, title("Residuals vs lagged residuals") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged348CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 348, title("Residuals vs year") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear348PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 348, title("Residuals vs lagged residuals") subtitle("ccode == 348") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged348PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 348, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2CONSUM if ccode == 348, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2CONSUM if ccode == 348, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348

* with intercept but no trend

dfuller res2CONSUM if ccode == 348, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2CONSUM if ccode == 348, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2CONSUM if ccode == 348, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res2PROD if ccode == 348, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3CONSUM if ccode == 348, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348
dfuller res3PROD if ccode == 348, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 348
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 348


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 356
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 356, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilCONSUMbarrelscap if ccode == 356, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilCONSUMbarrelscap if ccode == 356, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 356, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilCONSUMbarrelscap if ccode == 356, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilCONSUMbarrelscap if ccode == 356, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnoilPRODbarrelscap if ccode == 356, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap if ccode == 356, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap2 if ccode == 356, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller lnPWT_GDPplcap3 if ccode == 356, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 356


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 356, title("CONSUMResiduals vs year") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear356CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 356, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged356CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 356, title("PRODResiduals vs year") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear356PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 356, title("PRODResiduals vs lagged residuals") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged356PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 356, title("Residuals vs year") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear356CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 356, title("Residuals vs lagged residuals") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged356CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 356, title("Residuals vs year") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear356PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 356, title("Residuals vs lagged residuals") subtitle("ccode == 356") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged356PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 356, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2CONSUM if ccode == 356, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2CONSUM if ccode == 356, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356

* with intercept but no trend

dfuller res2CONSUM if ccode == 356, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2CONSUM if ccode == 356, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2CONSUM if ccode == 356, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res2PROD if ccode == 356, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3CONSUM if ccode == 356, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356
dfuller res3PROD if ccode == 356, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 356
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 356


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 360
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 360, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilCONSUMbarrelscap if ccode == 360, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilCONSUMbarrelscap if ccode == 360, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 360, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilCONSUMbarrelscap if ccode == 360, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilCONSUMbarrelscap if ccode == 360, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnoilPRODbarrelscap if ccode == 360, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap if ccode == 360, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap2 if ccode == 360, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller lnPWT_GDPplcap3 if ccode == 360, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 360


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 360, title("CONSUMResiduals vs year") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear360CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 360, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged360CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 360, title("PRODResiduals vs year") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear360PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 360, title("PRODResiduals vs lagged residuals") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged360PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 360, title("Residuals vs year") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear360CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 360, title("Residuals vs lagged residuals") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged360CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 360, title("Residuals vs year") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear360PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 360, title("Residuals vs lagged residuals") subtitle("ccode == 360") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged360PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 360, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2CONSUM if ccode == 360, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2CONSUM if ccode == 360, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360

* with intercept but no trend

dfuller res2CONSUM if ccode == 360, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2CONSUM if ccode == 360, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2CONSUM if ccode == 360, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res2PROD if ccode == 360, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3CONSUM if ccode == 360, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360
dfuller res3PROD if ccode == 360, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 360
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 360


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 364
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 364, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilCONSUMbarrelscap if ccode == 364, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilCONSUMbarrelscap if ccode == 364, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 364, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilCONSUMbarrelscap if ccode == 364, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilCONSUMbarrelscap if ccode == 364, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnoilPRODbarrelscap if ccode == 364, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap if ccode == 364, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap2 if ccode == 364, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller lnPWT_GDPplcap3 if ccode == 364, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 364


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 364, title("CONSUMResiduals vs year") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear364CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 364, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged364CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 364, title("PRODResiduals vs year") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear364PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 364, title("PRODResiduals vs lagged residuals") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged364PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 364, title("Residuals vs year") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear364CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 364, title("Residuals vs lagged residuals") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged364CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 364, title("Residuals vs year") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear364PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 364, title("Residuals vs lagged residuals") subtitle("ccode == 364") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged364PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 364, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2CONSUM if ccode == 364, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2CONSUM if ccode == 364, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364

* with intercept but no trend

dfuller res2CONSUM if ccode == 364, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2CONSUM if ccode == 364, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2CONSUM if ccode == 364, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res2PROD if ccode == 364, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3CONSUM if ccode == 364, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364
dfuller res3PROD if ccode == 364, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 364
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 364


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 372
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 372, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilCONSUMbarrelscap if ccode == 372, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilCONSUMbarrelscap if ccode == 372, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 372, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilCONSUMbarrelscap if ccode == 372, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilCONSUMbarrelscap if ccode == 372, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnoilPRODbarrelscap if ccode == 372, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap if ccode == 372, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap2 if ccode == 372, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller lnPWT_GDPplcap3 if ccode == 372, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 372


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 372, title("CONSUMResiduals vs year") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear372CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 372, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged372CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 372, title("PRODResiduals vs year") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear372PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 372, title("PRODResiduals vs lagged residuals") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged372PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 372, title("Residuals vs year") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear372CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 372, title("Residuals vs lagged residuals") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged372CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 372, title("Residuals vs year") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear372PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 372, title("Residuals vs lagged residuals") subtitle("ccode == 372") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged372PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 372, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2CONSUM if ccode == 372, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2CONSUM if ccode == 372, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372

* with intercept but no trend

dfuller res2CONSUM if ccode == 372, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2CONSUM if ccode == 372, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2CONSUM if ccode == 372, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res2PROD if ccode == 372, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3CONSUM if ccode == 372, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372
dfuller res3PROD if ccode == 372, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 372
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 372


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 376
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 376, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilCONSUMbarrelscap if ccode == 376, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilCONSUMbarrelscap if ccode == 376, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 376, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilCONSUMbarrelscap if ccode == 376, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilCONSUMbarrelscap if ccode == 376, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnoilPRODbarrelscap if ccode == 376, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap if ccode == 376, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap2 if ccode == 376, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller lnPWT_GDPplcap3 if ccode == 376, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 376


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 376, title("CONSUMResiduals vs year") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear376CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 376, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged376CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 376, title("PRODResiduals vs year") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear376PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 376, title("PRODResiduals vs lagged residuals") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged376PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 376, title("Residuals vs year") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear376CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 376, title("Residuals vs lagged residuals") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged376CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 376, title("Residuals vs year") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear376PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 376, title("Residuals vs lagged residuals") subtitle("ccode == 376") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged376PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 376, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2CONSUM if ccode == 376, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2CONSUM if ccode == 376, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376

* with intercept but no trend

dfuller res2CONSUM if ccode == 376, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2CONSUM if ccode == 376, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2CONSUM if ccode == 376, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res2PROD if ccode == 376, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3CONSUM if ccode == 376, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376
dfuller res3PROD if ccode == 376, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 376
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 376


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 380
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 380, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilCONSUMbarrelscap if ccode == 380, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilCONSUMbarrelscap if ccode == 380, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 380, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilCONSUMbarrelscap if ccode == 380, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilCONSUMbarrelscap if ccode == 380, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnoilPRODbarrelscap if ccode == 380, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap if ccode == 380, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap2 if ccode == 380, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller lnPWT_GDPplcap3 if ccode == 380, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 380


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 380, title("CONSUMResiduals vs year") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear380CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 380, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged380CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 380, title("PRODResiduals vs year") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear380PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 380, title("PRODResiduals vs lagged residuals") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged380PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 380, title("Residuals vs year") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear380CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 380, title("Residuals vs lagged residuals") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged380CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 380, title("Residuals vs year") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear380PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 380, title("Residuals vs lagged residuals") subtitle("ccode == 380") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged380PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 380, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2CONSUM if ccode == 380, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2CONSUM if ccode == 380, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380

* with intercept but no trend

dfuller res2CONSUM if ccode == 380, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2CONSUM if ccode == 380, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2CONSUM if ccode == 380, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res2PROD if ccode == 380, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3CONSUM if ccode == 380, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380
dfuller res3PROD if ccode == 380, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 380
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 380


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 384
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 384, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilCONSUMbarrelscap if ccode == 384, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilCONSUMbarrelscap if ccode == 384, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 384, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilCONSUMbarrelscap if ccode == 384, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilCONSUMbarrelscap if ccode == 384, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnoilPRODbarrelscap if ccode == 384, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap if ccode == 384, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap2 if ccode == 384, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller lnPWT_GDPplcap3 if ccode == 384, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 384


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 384, title("CONSUMResiduals vs year") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear384CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 384, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged384CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 384, title("PRODResiduals vs year") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear384PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 384, title("PRODResiduals vs lagged residuals") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged384PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 384, title("Residuals vs year") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear384CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 384, title("Residuals vs lagged residuals") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged384CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 384, title("Residuals vs year") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear384PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 384, title("Residuals vs lagged residuals") subtitle("ccode == 384") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged384PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 384, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2CONSUM if ccode == 384, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2CONSUM if ccode == 384, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384

* with intercept but no trend

dfuller res2CONSUM if ccode == 384, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2CONSUM if ccode == 384, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2CONSUM if ccode == 384, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res2PROD if ccode == 384, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3CONSUM if ccode == 384, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384
dfuller res3PROD if ccode == 384, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 384
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 384


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 388
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 388, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilCONSUMbarrelscap if ccode == 388, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilCONSUMbarrelscap if ccode == 388, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 388, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilCONSUMbarrelscap if ccode == 388, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilCONSUMbarrelscap if ccode == 388, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnoilPRODbarrelscap if ccode == 388, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap if ccode == 388, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap2 if ccode == 388, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller lnPWT_GDPplcap3 if ccode == 388, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 388


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 388, title("CONSUMResiduals vs year") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear388CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 388, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged388CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 388, title("PRODResiduals vs year") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear388PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 388, title("PRODResiduals vs lagged residuals") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged388PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 388, title("Residuals vs year") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear388CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 388, title("Residuals vs lagged residuals") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged388CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 388, title("Residuals vs year") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear388PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 388, title("Residuals vs lagged residuals") subtitle("ccode == 388") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged388PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 388, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2CONSUM if ccode == 388, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2CONSUM if ccode == 388, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388

* with intercept but no trend

dfuller res2CONSUM if ccode == 388, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2CONSUM if ccode == 388, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2CONSUM if ccode == 388, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res2PROD if ccode == 388, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3CONSUM if ccode == 388, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388
dfuller res3PROD if ccode == 388, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 388
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 388


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 392
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 392, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilCONSUMbarrelscap if ccode == 392, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilCONSUMbarrelscap if ccode == 392, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 392, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilCONSUMbarrelscap if ccode == 392, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilCONSUMbarrelscap if ccode == 392, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnoilPRODbarrelscap if ccode == 392, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap if ccode == 392, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap2 if ccode == 392, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller lnPWT_GDPplcap3 if ccode == 392, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 392


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 392, title("CONSUMResiduals vs year") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear392CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 392, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged392CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 392, title("PRODResiduals vs year") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear392PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 392, title("PRODResiduals vs lagged residuals") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged392PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 392, title("Residuals vs year") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear392CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 392, title("Residuals vs lagged residuals") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged392CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 392, title("Residuals vs year") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear392PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 392, title("Residuals vs lagged residuals") subtitle("ccode == 392") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged392PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 392, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2CONSUM if ccode == 392, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2CONSUM if ccode == 392, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392

* with intercept but no trend

dfuller res2CONSUM if ccode == 392, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2CONSUM if ccode == 392, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2CONSUM if ccode == 392, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res2PROD if ccode == 392, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3CONSUM if ccode == 392, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392
dfuller res3PROD if ccode == 392, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 392
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 392


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 400
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 400, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilCONSUMbarrelscap if ccode == 400, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilCONSUMbarrelscap if ccode == 400, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 400, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilCONSUMbarrelscap if ccode == 400, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilCONSUMbarrelscap if ccode == 400, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnoilPRODbarrelscap if ccode == 400, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap if ccode == 400, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap2 if ccode == 400, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller lnPWT_GDPplcap3 if ccode == 400, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 400


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 400, title("CONSUMResiduals vs year") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear400CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 400, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged400CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 400, title("PRODResiduals vs year") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear400PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 400, title("PRODResiduals vs lagged residuals") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged400PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 400, title("Residuals vs year") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear400CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 400, title("Residuals vs lagged residuals") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged400CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 400, title("Residuals vs year") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear400PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 400, title("Residuals vs lagged residuals") subtitle("ccode == 400") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged400PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 400, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2CONSUM if ccode == 400, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2CONSUM if ccode == 400, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400

* with intercept but no trend

dfuller res2CONSUM if ccode == 400, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2CONSUM if ccode == 400, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2CONSUM if ccode == 400, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res2PROD if ccode == 400, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3CONSUM if ccode == 400, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400
dfuller res3PROD if ccode == 400, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 400
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 400


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 404
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 404, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilCONSUMbarrelscap if ccode == 404, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilCONSUMbarrelscap if ccode == 404, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 404, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilCONSUMbarrelscap if ccode == 404, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilCONSUMbarrelscap if ccode == 404, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnoilPRODbarrelscap if ccode == 404, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap if ccode == 404, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap2 if ccode == 404, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller lnPWT_GDPplcap3 if ccode == 404, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 404


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 404, title("CONSUMResiduals vs year") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear404CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 404, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged404CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 404, title("PRODResiduals vs year") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear404PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 404, title("PRODResiduals vs lagged residuals") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged404PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 404, title("Residuals vs year") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear404CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 404, title("Residuals vs lagged residuals") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged404CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 404, title("Residuals vs year") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear404PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 404, title("Residuals vs lagged residuals") subtitle("ccode == 404") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged404PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 404, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2CONSUM if ccode == 404, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2CONSUM if ccode == 404, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404

* with intercept but no trend

dfuller res2CONSUM if ccode == 404, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2CONSUM if ccode == 404, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2CONSUM if ccode == 404, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res2PROD if ccode == 404, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3CONSUM if ccode == 404, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404
dfuller res3PROD if ccode == 404, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 404
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 404


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 410
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 410, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilCONSUMbarrelscap if ccode == 410, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilCONSUMbarrelscap if ccode == 410, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 410, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilCONSUMbarrelscap if ccode == 410, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilCONSUMbarrelscap if ccode == 410, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnoilPRODbarrelscap if ccode == 410, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap if ccode == 410, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap2 if ccode == 410, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller lnPWT_GDPplcap3 if ccode == 410, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 410


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 410, title("CONSUMResiduals vs year") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear410CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 410, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged410CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 410, title("PRODResiduals vs year") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear410PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 410, title("PRODResiduals vs lagged residuals") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged410PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 410, title("Residuals vs year") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear410CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 410, title("Residuals vs lagged residuals") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged410CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 410, title("Residuals vs year") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear410PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 410, title("Residuals vs lagged residuals") subtitle("ccode == 410") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged410PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 410, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2CONSUM if ccode == 410, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2CONSUM if ccode == 410, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410

* with intercept but no trend

dfuller res2CONSUM if ccode == 410, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2CONSUM if ccode == 410, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2CONSUM if ccode == 410, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res2PROD if ccode == 410, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3CONSUM if ccode == 410, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410
dfuller res3PROD if ccode == 410, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 410
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 410


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 458
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 458, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilCONSUMbarrelscap if ccode == 458, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilCONSUMbarrelscap if ccode == 458, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 458, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilCONSUMbarrelscap if ccode == 458, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilCONSUMbarrelscap if ccode == 458, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnoilPRODbarrelscap if ccode == 458, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap if ccode == 458, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap2 if ccode == 458, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller lnPWT_GDPplcap3 if ccode == 458, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 458


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 458, title("CONSUMResiduals vs year") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear458CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 458, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged458CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 458, title("PRODResiduals vs year") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear458PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 458, title("PRODResiduals vs lagged residuals") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged458PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 458, title("Residuals vs year") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear458CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 458, title("Residuals vs lagged residuals") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged458CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 458, title("Residuals vs year") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear458PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 458, title("Residuals vs lagged residuals") subtitle("ccode == 458") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged458PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 458, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2CONSUM if ccode == 458, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2CONSUM if ccode == 458, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458

* with intercept but no trend

dfuller res2CONSUM if ccode == 458, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2CONSUM if ccode == 458, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2CONSUM if ccode == 458, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res2PROD if ccode == 458, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3CONSUM if ccode == 458, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458
dfuller res3PROD if ccode == 458, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 458
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 458


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 484
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 484, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilCONSUMbarrelscap if ccode == 484, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilCONSUMbarrelscap if ccode == 484, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 484, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilCONSUMbarrelscap if ccode == 484, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilCONSUMbarrelscap if ccode == 484, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnoilPRODbarrelscap if ccode == 484, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap if ccode == 484, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap2 if ccode == 484, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller lnPWT_GDPplcap3 if ccode == 484, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 484


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 484, title("CONSUMResiduals vs year") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear484CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 484, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged484CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 484, title("PRODResiduals vs year") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear484PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 484, title("PRODResiduals vs lagged residuals") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged484PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 484, title("Residuals vs year") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear484CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 484, title("Residuals vs lagged residuals") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged484CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 484, title("Residuals vs year") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear484PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 484, title("Residuals vs lagged residuals") subtitle("ccode == 484") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged484PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 484, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2CONSUM if ccode == 484, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2CONSUM if ccode == 484, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484

* with intercept but no trend

dfuller res2CONSUM if ccode == 484, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2CONSUM if ccode == 484, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2CONSUM if ccode == 484, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res2PROD if ccode == 484, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3CONSUM if ccode == 484, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484
dfuller res3PROD if ccode == 484, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 484
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 484


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 504
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 504, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilCONSUMbarrelscap if ccode == 504, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilCONSUMbarrelscap if ccode == 504, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 504, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilCONSUMbarrelscap if ccode == 504, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilCONSUMbarrelscap if ccode == 504, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnoilPRODbarrelscap if ccode == 504, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap if ccode == 504, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap2 if ccode == 504, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller lnPWT_GDPplcap3 if ccode == 504, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 504


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 504, title("CONSUMResiduals vs year") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear504CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 504, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged504CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 504, title("PRODResiduals vs year") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear504PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 504, title("PRODResiduals vs lagged residuals") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged504PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 504, title("Residuals vs year") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear504CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 504, title("Residuals vs lagged residuals") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged504CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 504, title("Residuals vs year") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear504PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 504, title("Residuals vs lagged residuals") subtitle("ccode == 504") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged504PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 504, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2CONSUM if ccode == 504, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2CONSUM if ccode == 504, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504

* with intercept but no trend

dfuller res2CONSUM if ccode == 504, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2CONSUM if ccode == 504, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2CONSUM if ccode == 504, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res2PROD if ccode == 504, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3CONSUM if ccode == 504, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504
dfuller res3PROD if ccode == 504, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 504
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 504


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 528
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 528, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilCONSUMbarrelscap if ccode == 528, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilCONSUMbarrelscap if ccode == 528, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 528, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilCONSUMbarrelscap if ccode == 528, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilCONSUMbarrelscap if ccode == 528, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnoilPRODbarrelscap if ccode == 528, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap if ccode == 528, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap2 if ccode == 528, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller lnPWT_GDPplcap3 if ccode == 528, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 528


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 528, title("CONSUMResiduals vs year") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear528CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 528, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged528CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 528, title("PRODResiduals vs year") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear528PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 528, title("PRODResiduals vs lagged residuals") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged528PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 528, title("Residuals vs year") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear528CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 528, title("Residuals vs lagged residuals") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged528CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 528, title("Residuals vs year") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear528PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 528, title("Residuals vs lagged residuals") subtitle("ccode == 528") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged528PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 528, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2CONSUM if ccode == 528, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2CONSUM if ccode == 528, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528

* with intercept but no trend

dfuller res2CONSUM if ccode == 528, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2CONSUM if ccode == 528, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2CONSUM if ccode == 528, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res2PROD if ccode == 528, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3CONSUM if ccode == 528, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528
dfuller res3PROD if ccode == 528, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 528
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 528


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 554
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 554, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilCONSUMbarrelscap if ccode == 554, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilCONSUMbarrelscap if ccode == 554, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 554, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilCONSUMbarrelscap if ccode == 554, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilCONSUMbarrelscap if ccode == 554, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnoilPRODbarrelscap if ccode == 554, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap if ccode == 554, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap2 if ccode == 554, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller lnPWT_GDPplcap3 if ccode == 554, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 554


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 554, title("CONSUMResiduals vs year") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear554CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 554, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged554CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 554, title("PRODResiduals vs year") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear554PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 554, title("PRODResiduals vs lagged residuals") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged554PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 554, title("Residuals vs year") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear554CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 554, title("Residuals vs lagged residuals") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged554CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 554, title("Residuals vs year") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear554PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 554, title("Residuals vs lagged residuals") subtitle("ccode == 554") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged554PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 554, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2CONSUM if ccode == 554, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2CONSUM if ccode == 554, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554

* with intercept but no trend

dfuller res2CONSUM if ccode == 554, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2CONSUM if ccode == 554, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2CONSUM if ccode == 554, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res2PROD if ccode == 554, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3CONSUM if ccode == 554, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554
dfuller res3PROD if ccode == 554, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 554
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 554


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 558
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 558, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilCONSUMbarrelscap if ccode == 558, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilCONSUMbarrelscap if ccode == 558, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 558, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilCONSUMbarrelscap if ccode == 558, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilCONSUMbarrelscap if ccode == 558, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnoilPRODbarrelscap if ccode == 558, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap if ccode == 558, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap2 if ccode == 558, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller lnPWT_GDPplcap3 if ccode == 558, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 558


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 558, title("CONSUMResiduals vs year") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear558CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 558, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged558CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 558, title("PRODResiduals vs year") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear558PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 558, title("PRODResiduals vs lagged residuals") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged558PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 558, title("Residuals vs year") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear558CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 558, title("Residuals vs lagged residuals") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged558CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 558, title("Residuals vs year") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear558PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 558, title("Residuals vs lagged residuals") subtitle("ccode == 558") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged558PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 558, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2CONSUM if ccode == 558, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2CONSUM if ccode == 558, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558

* with intercept but no trend

dfuller res2CONSUM if ccode == 558, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2CONSUM if ccode == 558, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2CONSUM if ccode == 558, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res2PROD if ccode == 558, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3CONSUM if ccode == 558, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558
dfuller res3PROD if ccode == 558, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 558
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 558


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 566
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 566, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilCONSUMbarrelscap if ccode == 566, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilCONSUMbarrelscap if ccode == 566, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 566, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilCONSUMbarrelscap if ccode == 566, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilCONSUMbarrelscap if ccode == 566, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnoilPRODbarrelscap if ccode == 566, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap if ccode == 566, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap2 if ccode == 566, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller lnPWT_GDPplcap3 if ccode == 566, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 566


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 566, title("CONSUMResiduals vs year") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear566CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 566, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged566CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 566, title("PRODResiduals vs year") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear566PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 566, title("PRODResiduals vs lagged residuals") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged566PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 566, title("Residuals vs year") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear566CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 566, title("Residuals vs lagged residuals") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged566CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 566, title("Residuals vs year") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear566PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 566, title("Residuals vs lagged residuals") subtitle("ccode == 566") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged566PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 566, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2CONSUM if ccode == 566, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2CONSUM if ccode == 566, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566

* with intercept but no trend

dfuller res2CONSUM if ccode == 566, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2CONSUM if ccode == 566, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2CONSUM if ccode == 566, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res2PROD if ccode == 566, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3CONSUM if ccode == 566, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566
dfuller res3PROD if ccode == 566, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 566
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 566


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 578
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 578, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilCONSUMbarrelscap if ccode == 578, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilCONSUMbarrelscap if ccode == 578, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 578, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilCONSUMbarrelscap if ccode == 578, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilCONSUMbarrelscap if ccode == 578, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnoilPRODbarrelscap if ccode == 578, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap if ccode == 578, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap2 if ccode == 578, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller lnPWT_GDPplcap3 if ccode == 578, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 578


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 578, title("CONSUMResiduals vs year") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear578CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 578, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged578CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 578, title("PRODResiduals vs year") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear578PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 578, title("PRODResiduals vs lagged residuals") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged578PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 578, title("Residuals vs year") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear578CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 578, title("Residuals vs lagged residuals") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged578CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 578, title("Residuals vs year") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear578PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 578, title("Residuals vs lagged residuals") subtitle("ccode == 578") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged578PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 578, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2CONSUM if ccode == 578, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2CONSUM if ccode == 578, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578

* with intercept but no trend

dfuller res2CONSUM if ccode == 578, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2CONSUM if ccode == 578, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2CONSUM if ccode == 578, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res2PROD if ccode == 578, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3CONSUM if ccode == 578, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578
dfuller res3PROD if ccode == 578, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 578
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 578


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 586
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 586, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilCONSUMbarrelscap if ccode == 586, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilCONSUMbarrelscap if ccode == 586, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 586, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilCONSUMbarrelscap if ccode == 586, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilCONSUMbarrelscap if ccode == 586, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnoilPRODbarrelscap if ccode == 586, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap if ccode == 586, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap2 if ccode == 586, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller lnPWT_GDPplcap3 if ccode == 586, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 586


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 586, title("CONSUMResiduals vs year") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear586CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 586, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged586CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 586, title("PRODResiduals vs year") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear586PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 586, title("PRODResiduals vs lagged residuals") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged586PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 586, title("Residuals vs year") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear586CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 586, title("Residuals vs lagged residuals") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged586CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 586, title("Residuals vs year") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear586PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 586, title("Residuals vs lagged residuals") subtitle("ccode == 586") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged586PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 586, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2CONSUM if ccode == 586, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2CONSUM if ccode == 586, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586

* with intercept but no trend

dfuller res2CONSUM if ccode == 586, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2CONSUM if ccode == 586, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2CONSUM if ccode == 586, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res2PROD if ccode == 586, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3CONSUM if ccode == 586, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586
dfuller res3PROD if ccode == 586, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 586
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 586


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 590
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 590, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilCONSUMbarrelscap if ccode == 590, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilCONSUMbarrelscap if ccode == 590, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 590, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilCONSUMbarrelscap if ccode == 590, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilCONSUMbarrelscap if ccode == 590, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnoilPRODbarrelscap if ccode == 590, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap if ccode == 590, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap2 if ccode == 590, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller lnPWT_GDPplcap3 if ccode == 590, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 590


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 590, title("CONSUMResiduals vs year") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear590CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 590, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged590CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 590, title("PRODResiduals vs year") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear590PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 590, title("PRODResiduals vs lagged residuals") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged590PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 590, title("Residuals vs year") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear590CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 590, title("Residuals vs lagged residuals") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged590CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 590, title("Residuals vs year") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear590PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 590, title("Residuals vs lagged residuals") subtitle("ccode == 590") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged590PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 590, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2CONSUM if ccode == 590, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2CONSUM if ccode == 590, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590

* with intercept but no trend

dfuller res2CONSUM if ccode == 590, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2CONSUM if ccode == 590, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2CONSUM if ccode == 590, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res2PROD if ccode == 590, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3CONSUM if ccode == 590, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590
dfuller res3PROD if ccode == 590, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 590
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 590


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 604
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 604, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilCONSUMbarrelscap if ccode == 604, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilCONSUMbarrelscap if ccode == 604, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 604, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilCONSUMbarrelscap if ccode == 604, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilCONSUMbarrelscap if ccode == 604, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnoilPRODbarrelscap if ccode == 604, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap if ccode == 604, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap2 if ccode == 604, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller lnPWT_GDPplcap3 if ccode == 604, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 604


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 604, title("CONSUMResiduals vs year") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear604CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 604, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged604CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 604, title("PRODResiduals vs year") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear604PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 604, title("PRODResiduals vs lagged residuals") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged604PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 604, title("Residuals vs year") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear604CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 604, title("Residuals vs lagged residuals") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged604CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 604, title("Residuals vs year") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear604PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 604, title("Residuals vs lagged residuals") subtitle("ccode == 604") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged604PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 604, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2CONSUM if ccode == 604, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2CONSUM if ccode == 604, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604

* with intercept but no trend

dfuller res2CONSUM if ccode == 604, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2CONSUM if ccode == 604, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2CONSUM if ccode == 604, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res2PROD if ccode == 604, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3CONSUM if ccode == 604, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604
dfuller res3PROD if ccode == 604, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 604
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 604


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 608
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 608, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilCONSUMbarrelscap if ccode == 608, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilCONSUMbarrelscap if ccode == 608, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 608, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilCONSUMbarrelscap if ccode == 608, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilCONSUMbarrelscap if ccode == 608, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnoilPRODbarrelscap if ccode == 608, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap if ccode == 608, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap2 if ccode == 608, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller lnPWT_GDPplcap3 if ccode == 608, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 608


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 608, title("CONSUMResiduals vs year") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear608CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 608, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged608CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 608, title("PRODResiduals vs year") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear608PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 608, title("PRODResiduals vs lagged residuals") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged608PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 608, title("Residuals vs year") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear608CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 608, title("Residuals vs lagged residuals") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged608CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 608, title("Residuals vs year") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear608PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 608, title("Residuals vs lagged residuals") subtitle("ccode == 608") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged608PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 608, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2CONSUM if ccode == 608, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2CONSUM if ccode == 608, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608

* with intercept but no trend

dfuller res2CONSUM if ccode == 608, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2CONSUM if ccode == 608, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2CONSUM if ccode == 608, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res2PROD if ccode == 608, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3CONSUM if ccode == 608, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608
dfuller res3PROD if ccode == 608, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 608
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 608


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 616
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 616, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilCONSUMbarrelscap if ccode == 616, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilCONSUMbarrelscap if ccode == 616, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 616, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilCONSUMbarrelscap if ccode == 616, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilCONSUMbarrelscap if ccode == 616, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnoilPRODbarrelscap if ccode == 616, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap if ccode == 616, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap2 if ccode == 616, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller lnPWT_GDPplcap3 if ccode == 616, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 616


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 616, title("CONSUMResiduals vs year") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear616CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 616, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged616CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 616, title("PRODResiduals vs year") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear616PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 616, title("PRODResiduals vs lagged residuals") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged616PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 616, title("Residuals vs year") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear616CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 616, title("Residuals vs lagged residuals") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged616CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 616, title("Residuals vs year") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear616PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 616, title("Residuals vs lagged residuals") subtitle("ccode == 616") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged616PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 616, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2CONSUM if ccode == 616, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2CONSUM if ccode == 616, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616

* with intercept but no trend

dfuller res2CONSUM if ccode == 616, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2CONSUM if ccode == 616, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2CONSUM if ccode == 616, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res2PROD if ccode == 616, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3CONSUM if ccode == 616, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616
dfuller res3PROD if ccode == 616, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 616
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 616


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 620
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 620, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilCONSUMbarrelscap if ccode == 620, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilCONSUMbarrelscap if ccode == 620, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 620, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilCONSUMbarrelscap if ccode == 620, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilCONSUMbarrelscap if ccode == 620, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnoilPRODbarrelscap if ccode == 620, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap if ccode == 620, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap2 if ccode == 620, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller lnPWT_GDPplcap3 if ccode == 620, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 620


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 620, title("CONSUMResiduals vs year") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear620CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 620, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged620CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 620, title("PRODResiduals vs year") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear620PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 620, title("PRODResiduals vs lagged residuals") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged620PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 620, title("Residuals vs year") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear620CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 620, title("Residuals vs lagged residuals") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged620CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 620, title("Residuals vs year") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear620PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 620, title("Residuals vs lagged residuals") subtitle("ccode == 620") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged620PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 620, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2CONSUM if ccode == 620, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2CONSUM if ccode == 620, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620

* with intercept but no trend

dfuller res2CONSUM if ccode == 620, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2CONSUM if ccode == 620, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2CONSUM if ccode == 620, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res2PROD if ccode == 620, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3CONSUM if ccode == 620, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620
dfuller res3PROD if ccode == 620, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 620
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 620


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 642
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 642, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilCONSUMbarrelscap if ccode == 642, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilCONSUMbarrelscap if ccode == 642, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 642, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilCONSUMbarrelscap if ccode == 642, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilCONSUMbarrelscap if ccode == 642, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnoilPRODbarrelscap if ccode == 642, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap if ccode == 642, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap2 if ccode == 642, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller lnPWT_GDPplcap3 if ccode == 642, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 642


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 642, title("CONSUMResiduals vs year") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear642CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 642, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged642CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 642, title("PRODResiduals vs year") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear642PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 642, title("PRODResiduals vs lagged residuals") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged642PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 642, title("Residuals vs year") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear642CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 642, title("Residuals vs lagged residuals") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged642CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 642, title("Residuals vs year") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear642PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 642, title("Residuals vs lagged residuals") subtitle("ccode == 642") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged642PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 642, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2CONSUM if ccode == 642, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2CONSUM if ccode == 642, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642

* with intercept but no trend

dfuller res2CONSUM if ccode == 642, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2CONSUM if ccode == 642, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2CONSUM if ccode == 642, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res2PROD if ccode == 642, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3CONSUM if ccode == 642, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642
dfuller res3PROD if ccode == 642, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 642
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 642


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 643
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 643, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilCONSUMbarrelscap if ccode == 643, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilCONSUMbarrelscap if ccode == 643, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 643, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilCONSUMbarrelscap if ccode == 643, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilCONSUMbarrelscap if ccode == 643, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnoilPRODbarrelscap if ccode == 643, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap if ccode == 643, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap2 if ccode == 643, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller lnPWT_GDPplcap3 if ccode == 643, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 643


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 643, title("CONSUMResiduals vs year") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear643CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 643, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged643CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 643, title("PRODResiduals vs year") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear643PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 643, title("PRODResiduals vs lagged residuals") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged643PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 643, title("Residuals vs year") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear643CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 643, title("Residuals vs lagged residuals") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged643CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 643, title("Residuals vs year") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear643PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 643, title("Residuals vs lagged residuals") subtitle("ccode == 643") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged643PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 643, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2CONSUM if ccode == 643, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2CONSUM if ccode == 643, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643

* with intercept but no trend

dfuller res2CONSUM if ccode == 643, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2CONSUM if ccode == 643, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2CONSUM if ccode == 643, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res2PROD if ccode == 643, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3CONSUM if ccode == 643, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643
dfuller res3PROD if ccode == 643, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 643
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 643


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 686
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 686, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilCONSUMbarrelscap if ccode == 686, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilCONSUMbarrelscap if ccode == 686, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 686, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilCONSUMbarrelscap if ccode == 686, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilCONSUMbarrelscap if ccode == 686, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnoilPRODbarrelscap if ccode == 686, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap if ccode == 686, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap2 if ccode == 686, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller lnPWT_GDPplcap3 if ccode == 686, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 686


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 686, title("CONSUMResiduals vs year") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear686CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 686, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged686CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 686, title("PRODResiduals vs year") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear686PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 686, title("PRODResiduals vs lagged residuals") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged686PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 686, title("Residuals vs year") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear686CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 686, title("Residuals vs lagged residuals") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged686CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 686, title("Residuals vs year") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear686PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 686, title("Residuals vs lagged residuals") subtitle("ccode == 686") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged686PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 686, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2CONSUM if ccode == 686, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2CONSUM if ccode == 686, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686

* with intercept but no trend

dfuller res2CONSUM if ccode == 686, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2CONSUM if ccode == 686, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2CONSUM if ccode == 686, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res2PROD if ccode == 686, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3CONSUM if ccode == 686, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686
dfuller res3PROD if ccode == 686, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 686
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 686


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 702
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 702, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilCONSUMbarrelscap if ccode == 702, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilCONSUMbarrelscap if ccode == 702, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 702, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilCONSUMbarrelscap if ccode == 702, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilCONSUMbarrelscap if ccode == 702, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnoilPRODbarrelscap if ccode == 702, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap if ccode == 702, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap2 if ccode == 702, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller lnPWT_GDPplcap3 if ccode == 702, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 702


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 702, title("CONSUMResiduals vs year") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear702CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 702, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged702CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 702, title("PRODResiduals vs year") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear702PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 702, title("PRODResiduals vs lagged residuals") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged702PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 702, title("Residuals vs year") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear702CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 702, title("Residuals vs lagged residuals") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged702CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 702, title("Residuals vs year") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear702PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 702, title("Residuals vs lagged residuals") subtitle("ccode == 702") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged702PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 702, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2CONSUM if ccode == 702, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2CONSUM if ccode == 702, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702

* with intercept but no trend

dfuller res2CONSUM if ccode == 702, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2CONSUM if ccode == 702, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2CONSUM if ccode == 702, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res2PROD if ccode == 702, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3CONSUM if ccode == 702, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702
dfuller res3PROD if ccode == 702, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 702
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 702


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 705
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 705, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilCONSUMbarrelscap if ccode == 705, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilCONSUMbarrelscap if ccode == 705, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 705, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilCONSUMbarrelscap if ccode == 705, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilCONSUMbarrelscap if ccode == 705, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnoilPRODbarrelscap if ccode == 705, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap if ccode == 705, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap2 if ccode == 705, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller lnPWT_GDPplcap3 if ccode == 705, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 705


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 705, title("CONSUMResiduals vs year") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear705CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 705, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged705CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 705, title("PRODResiduals vs year") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear705PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 705, title("PRODResiduals vs lagged residuals") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged705PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 705, title("Residuals vs year") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear705CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 705, title("Residuals vs lagged residuals") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged705CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 705, title("Residuals vs year") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear705PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 705, title("Residuals vs lagged residuals") subtitle("ccode == 705") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged705PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 705, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2CONSUM if ccode == 705, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2CONSUM if ccode == 705, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705

* with intercept but no trend

dfuller res2CONSUM if ccode == 705, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2CONSUM if ccode == 705, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2CONSUM if ccode == 705, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res2PROD if ccode == 705, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3CONSUM if ccode == 705, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705
dfuller res3PROD if ccode == 705, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 705
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 705


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 710
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 710, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilCONSUMbarrelscap if ccode == 710, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilCONSUMbarrelscap if ccode == 710, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 710, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilCONSUMbarrelscap if ccode == 710, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilCONSUMbarrelscap if ccode == 710, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnoilPRODbarrelscap if ccode == 710, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap if ccode == 710, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap2 if ccode == 710, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller lnPWT_GDPplcap3 if ccode == 710, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 710


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 710, title("CONSUMResiduals vs year") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear710CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 710, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged710CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 710, title("PRODResiduals vs year") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear710PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 710, title("PRODResiduals vs lagged residuals") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged710PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 710, title("Residuals vs year") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear710CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 710, title("Residuals vs lagged residuals") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged710CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 710, title("Residuals vs year") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear710PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 710, title("Residuals vs lagged residuals") subtitle("ccode == 710") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged710PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 710, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2CONSUM if ccode == 710, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2CONSUM if ccode == 710, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710

* with intercept but no trend

dfuller res2CONSUM if ccode == 710, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2CONSUM if ccode == 710, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2CONSUM if ccode == 710, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res2PROD if ccode == 710, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3CONSUM if ccode == 710, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710
dfuller res3PROD if ccode == 710, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 710
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 710


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 724
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 724, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilCONSUMbarrelscap if ccode == 724, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilCONSUMbarrelscap if ccode == 724, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 724, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilCONSUMbarrelscap if ccode == 724, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilCONSUMbarrelscap if ccode == 724, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnoilPRODbarrelscap if ccode == 724, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap if ccode == 724, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap2 if ccode == 724, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller lnPWT_GDPplcap3 if ccode == 724, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 724


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 724, title("CONSUMResiduals vs year") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear724CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 724, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged724CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 724, title("PRODResiduals vs year") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear724PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 724, title("PRODResiduals vs lagged residuals") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged724PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 724, title("Residuals vs year") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear724CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 724, title("Residuals vs lagged residuals") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged724CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 724, title("Residuals vs year") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear724PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 724, title("Residuals vs lagged residuals") subtitle("ccode == 724") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged724PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 724, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2CONSUM if ccode == 724, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2CONSUM if ccode == 724, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724

* with intercept but no trend

dfuller res2CONSUM if ccode == 724, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2CONSUM if ccode == 724, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2CONSUM if ccode == 724, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res2PROD if ccode == 724, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3CONSUM if ccode == 724, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724
dfuller res3PROD if ccode == 724, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 724
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 724


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 752
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 752, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilCONSUMbarrelscap if ccode == 752, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilCONSUMbarrelscap if ccode == 752, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 752, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilCONSUMbarrelscap if ccode == 752, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilCONSUMbarrelscap if ccode == 752, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnoilPRODbarrelscap if ccode == 752, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap if ccode == 752, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap2 if ccode == 752, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller lnPWT_GDPplcap3 if ccode == 752, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 752


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 752, title("CONSUMResiduals vs year") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear752CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 752, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged752CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 752, title("PRODResiduals vs year") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear752PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 752, title("PRODResiduals vs lagged residuals") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged752PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 752, title("Residuals vs year") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear752CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 752, title("Residuals vs lagged residuals") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged752CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 752, title("Residuals vs year") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear752PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 752, title("Residuals vs lagged residuals") subtitle("ccode == 752") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged752PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 752, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2CONSUM if ccode == 752, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2CONSUM if ccode == 752, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752

* with intercept but no trend

dfuller res2CONSUM if ccode == 752, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2CONSUM if ccode == 752, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2CONSUM if ccode == 752, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res2PROD if ccode == 752, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3CONSUM if ccode == 752, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752
dfuller res3PROD if ccode == 752, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 752
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 752


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 756
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 756, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilCONSUMbarrelscap if ccode == 756, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilCONSUMbarrelscap if ccode == 756, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 756, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilCONSUMbarrelscap if ccode == 756, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilCONSUMbarrelscap if ccode == 756, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnoilPRODbarrelscap if ccode == 756, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap if ccode == 756, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap2 if ccode == 756, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller lnPWT_GDPplcap3 if ccode == 756, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 756


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 756, title("CONSUMResiduals vs year") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear756CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 756, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged756CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 756, title("PRODResiduals vs year") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear756PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 756, title("PRODResiduals vs lagged residuals") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged756PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 756, title("Residuals vs year") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear756CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 756, title("Residuals vs lagged residuals") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged756CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 756, title("Residuals vs year") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear756PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 756, title("Residuals vs lagged residuals") subtitle("ccode == 756") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged756PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 756, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2CONSUM if ccode == 756, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2CONSUM if ccode == 756, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756

* with intercept but no trend

dfuller res2CONSUM if ccode == 756, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2CONSUM if ccode == 756, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2CONSUM if ccode == 756, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res2PROD if ccode == 756, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3CONSUM if ccode == 756, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756
dfuller res3PROD if ccode == 756, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 756
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 756


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 760
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 760, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilCONSUMbarrelscap if ccode == 760, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilCONSUMbarrelscap if ccode == 760, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 760, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilCONSUMbarrelscap if ccode == 760, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilCONSUMbarrelscap if ccode == 760, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnoilPRODbarrelscap if ccode == 760, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap if ccode == 760, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap2 if ccode == 760, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller lnPWT_GDPplcap3 if ccode == 760, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 760


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 760, title("CONSUMResiduals vs year") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear760CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 760, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged760CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 760, title("PRODResiduals vs year") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear760PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 760, title("PRODResiduals vs lagged residuals") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged760PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 760, title("Residuals vs year") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear760CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 760, title("Residuals vs lagged residuals") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged760CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 760, title("Residuals vs year") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear760PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 760, title("Residuals vs lagged residuals") subtitle("ccode == 760") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged760PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 760, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2CONSUM if ccode == 760, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2CONSUM if ccode == 760, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760

* with intercept but no trend

dfuller res2CONSUM if ccode == 760, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2CONSUM if ccode == 760, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2CONSUM if ccode == 760, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res2PROD if ccode == 760, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3CONSUM if ccode == 760, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760
dfuller res3PROD if ccode == 760, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 760
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 760


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 788
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 788, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilCONSUMbarrelscap if ccode == 788, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilCONSUMbarrelscap if ccode == 788, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 788, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilCONSUMbarrelscap if ccode == 788, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilCONSUMbarrelscap if ccode == 788, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnoilPRODbarrelscap if ccode == 788, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap if ccode == 788, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap2 if ccode == 788, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller lnPWT_GDPplcap3 if ccode == 788, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 788


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 788, title("CONSUMResiduals vs year") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear788CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 788, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged788CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 788, title("PRODResiduals vs year") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear788PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 788, title("PRODResiduals vs lagged residuals") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged788PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 788, title("Residuals vs year") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear788CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 788, title("Residuals vs lagged residuals") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged788CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 788, title("Residuals vs year") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear788PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 788, title("Residuals vs lagged residuals") subtitle("ccode == 788") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged788PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 788, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2CONSUM if ccode == 788, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2CONSUM if ccode == 788, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788

* with intercept but no trend

dfuller res2CONSUM if ccode == 788, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2CONSUM if ccode == 788, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2CONSUM if ccode == 788, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res2PROD if ccode == 788, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3CONSUM if ccode == 788, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788
dfuller res3PROD if ccode == 788, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 788
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 788


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 792
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 792, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilCONSUMbarrelscap if ccode == 792, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilCONSUMbarrelscap if ccode == 792, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 792, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilCONSUMbarrelscap if ccode == 792, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilCONSUMbarrelscap if ccode == 792, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnoilPRODbarrelscap if ccode == 792, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap if ccode == 792, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap2 if ccode == 792, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller lnPWT_GDPplcap3 if ccode == 792, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 792


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 792, title("CONSUMResiduals vs year") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear792CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 792, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged792CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 792, title("PRODResiduals vs year") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear792PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 792, title("PRODResiduals vs lagged residuals") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged792PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 792, title("Residuals vs year") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear792CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 792, title("Residuals vs lagged residuals") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged792CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 792, title("Residuals vs year") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear792PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 792, title("Residuals vs lagged residuals") subtitle("ccode == 792") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged792PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 792, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2CONSUM if ccode == 792, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2CONSUM if ccode == 792, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792

* with intercept but no trend

dfuller res2CONSUM if ccode == 792, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2CONSUM if ccode == 792, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2CONSUM if ccode == 792, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res2PROD if ccode == 792, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3CONSUM if ccode == 792, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792
dfuller res3PROD if ccode == 792, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 792
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 792


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 818
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 818, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilCONSUMbarrelscap if ccode == 818, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilCONSUMbarrelscap if ccode == 818, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 818, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilCONSUMbarrelscap if ccode == 818, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilCONSUMbarrelscap if ccode == 818, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnoilPRODbarrelscap if ccode == 818, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap if ccode == 818, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap2 if ccode == 818, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller lnPWT_GDPplcap3 if ccode == 818, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 818


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 818, title("CONSUMResiduals vs year") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear818CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 818, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged818CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 818, title("PRODResiduals vs year") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear818PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 818, title("PRODResiduals vs lagged residuals") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged818PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 818, title("Residuals vs year") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear818CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 818, title("Residuals vs lagged residuals") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged818CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 818, title("Residuals vs year") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear818PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 818, title("Residuals vs lagged residuals") subtitle("ccode == 818") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged818PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 818, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2CONSUM if ccode == 818, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2CONSUM if ccode == 818, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818

* with intercept but no trend

dfuller res2CONSUM if ccode == 818, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2CONSUM if ccode == 818, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2CONSUM if ccode == 818, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res2PROD if ccode == 818, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3CONSUM if ccode == 818, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818
dfuller res3PROD if ccode == 818, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 818
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 818


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 826
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 826, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilCONSUMbarrelscap if ccode == 826, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilCONSUMbarrelscap if ccode == 826, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 826, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilCONSUMbarrelscap if ccode == 826, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilCONSUMbarrelscap if ccode == 826, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnoilPRODbarrelscap if ccode == 826, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap if ccode == 826, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap2 if ccode == 826, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller lnPWT_GDPplcap3 if ccode == 826, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 826


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 826, title("CONSUMResiduals vs year") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear826CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 826, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged826CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 826, title("PRODResiduals vs year") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear826PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 826, title("PRODResiduals vs lagged residuals") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged826PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 826, title("Residuals vs year") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear826CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 826, title("Residuals vs lagged residuals") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged826CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 826, title("Residuals vs year") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear826PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 826, title("Residuals vs lagged residuals") subtitle("ccode == 826") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged826PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 826, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2CONSUM if ccode == 826, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2CONSUM if ccode == 826, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826

* with intercept but no trend

dfuller res2CONSUM if ccode == 826, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2CONSUM if ccode == 826, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2CONSUM if ccode == 826, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res2PROD if ccode == 826, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3CONSUM if ccode == 826, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826
dfuller res3PROD if ccode == 826, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 826
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 826


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 834
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 834, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilCONSUMbarrelscap if ccode == 834, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilCONSUMbarrelscap if ccode == 834, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 834, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilCONSUMbarrelscap if ccode == 834, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilCONSUMbarrelscap if ccode == 834, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnoilPRODbarrelscap if ccode == 834, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap if ccode == 834, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap2 if ccode == 834, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller lnPWT_GDPplcap3 if ccode == 834, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 834


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 834, title("CONSUMResiduals vs year") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear834CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 834, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged834CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 834, title("PRODResiduals vs year") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear834PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 834, title("PRODResiduals vs lagged residuals") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged834PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 834, title("Residuals vs year") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear834CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 834, title("Residuals vs lagged residuals") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged834CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 834, title("Residuals vs year") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear834PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 834, title("Residuals vs lagged residuals") subtitle("ccode == 834") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged834PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 834, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2CONSUM if ccode == 834, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2CONSUM if ccode == 834, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834

* with intercept but no trend

dfuller res2CONSUM if ccode == 834, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2CONSUM if ccode == 834, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2CONSUM if ccode == 834, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res2PROD if ccode == 834, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3CONSUM if ccode == 834, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834
dfuller res3PROD if ccode == 834, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 834
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 834


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 840
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 840, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilCONSUMbarrelscap if ccode == 840, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilCONSUMbarrelscap if ccode == 840, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 840, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilCONSUMbarrelscap if ccode == 840, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilCONSUMbarrelscap if ccode == 840, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnoilPRODbarrelscap if ccode == 840, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap if ccode == 840, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap2 if ccode == 840, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller lnPWT_GDPplcap3 if ccode == 840, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 840


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 840, title("CONSUMResiduals vs year") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear840CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 840, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged840CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 840, title("PRODResiduals vs year") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear840PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 840, title("PRODResiduals vs lagged residuals") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged840PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 840, title("Residuals vs year") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear840CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 840, title("Residuals vs lagged residuals") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged840CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 840, title("Residuals vs year") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear840PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 840, title("Residuals vs lagged residuals") subtitle("ccode == 840") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged840PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 840, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2CONSUM if ccode == 840, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2CONSUM if ccode == 840, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840

* with intercept but no trend

dfuller res2CONSUM if ccode == 840, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2CONSUM if ccode == 840, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2CONSUM if ccode == 840, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res2PROD if ccode == 840, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3CONSUM if ccode == 840, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840
dfuller res3PROD if ccode == 840, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 840
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 840


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 858
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 858, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilCONSUMbarrelscap if ccode == 858, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilCONSUMbarrelscap if ccode == 858, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 858, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilCONSUMbarrelscap if ccode == 858, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilCONSUMbarrelscap if ccode == 858, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnoilPRODbarrelscap if ccode == 858, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap if ccode == 858, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap2 if ccode == 858, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller lnPWT_GDPplcap3 if ccode == 858, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 858


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 858, title("CONSUMResiduals vs year") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear858CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 858, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged858CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 858, title("PRODResiduals vs year") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear858PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 858, title("PRODResiduals vs lagged residuals") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged858PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 858, title("Residuals vs year") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear858CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 858, title("Residuals vs lagged residuals") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged858CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 858, title("Residuals vs year") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear858PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 858, title("Residuals vs lagged residuals") subtitle("ccode == 858") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged858PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 858, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2CONSUM if ccode == 858, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2CONSUM if ccode == 858, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858

* with intercept but no trend

dfuller res2CONSUM if ccode == 858, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2CONSUM if ccode == 858, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2CONSUM if ccode == 858, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res2PROD if ccode == 858, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3CONSUM if ccode == 858, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858
dfuller res3PROD if ccode == 858, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 858
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 858


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)



****
* ccode == 862
****

* (1) Augmented Dickey-Fuller test

* with intercept and trend

dfuller lnoilCONSUMbarrelscap if ccode == 862, regress trend lags(1)
replace nURl1CONSUMp5 = nURl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl1CONSUMp10 = nURl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilCONSUMbarrelscap if ccode == 862, regress trend lags(2)
replace nURl2CONSUMp5 = nURl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl2CONSUMp10 = nURl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilCONSUMbarrelscap if ccode == 862, regress trend lags(3)
replace nURl3CONSUMp5 = nURl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl3CONSUMp10 = nURl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress trend lags(1)
replace nURl1PRODp5 = nURl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl1PRODp10 = nURl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress trend lags(2)
replace nURl2PRODp5 = nURl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl2PRODp10 = nURl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress trend lags(3)
replace nURl3PRODp5 = nURl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl3PRODp10 = nURl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress trend lags(1)
replace nURl1GDPp5 = nURl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl1GDPp10 = nURl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress trend lags(2)
replace nURl2GDPp5 = nURl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl2GDPp10 = nURl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress trend lags(3)
replace nURl3GDPp5 = nURl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl3GDPp10 = nURl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress trend lags(1)
replace nURl1GDP2_p5 = nURl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl1GDP2_p10 = nURl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress trend lags(2)
replace nURl2GDP2_p5 = nURl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl2GDP2_p10 = nURl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress trend lags(3)
replace nURl3GDP2_p5 = nURl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl3GDP2_p10 = nURl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress trend lags(1)
replace nURl1GDP3_p5 = nURl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl1GDP3_p10 = nURl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress trend lags(2)
replace nURl2GDP3_p5 = nURl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl2GDP3_p10 = nURl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress trend lags(3)
replace nURl3GDP3_p5 = nURl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURl3GDP3_p10 = nURl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862

* with intercept but no trend

dfuller lnoilCONSUMbarrelscap if ccode == 862, regress lags(1)
replace nURntl1CONSUMp5 = nURntl1CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl1CONSUMp10 = nURntl1CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilCONSUMbarrelscap if ccode == 862, regress lags(2)
replace nURntl2CONSUMp5 = nURntl2CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl2CONSUMp10 = nURntl2CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilCONSUMbarrelscap if ccode == 862, regress lags(3)
replace nURntl3CONSUMp5 = nURntl3CONSUMp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl3CONSUMp10 = nURntl3CONSUMp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress lags(1)
replace nURntl1PRODp5 = nURntl1PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl1PRODp10 = nURntl1PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress lags(2)
replace nURntl2PRODp5 = nURntl2PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl2PRODp10 = nURntl2PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnoilPRODbarrelscap if ccode == 862, regress lags(3)
replace nURntl3PRODp5 = nURntl3PRODp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl3PRODp10 = nURntl3PRODp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress lags(1)
replace nURntl1GDPp5 = nURntl1GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl1GDPp10 = nURntl1GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress lags(2)
replace nURntl2GDPp5 = nURntl2GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl2GDPp10 = nURntl2GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap if ccode == 862, regress lags(3)
replace nURntl3GDPp5 = nURntl3GDPp5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl3GDPp10 = nURntl3GDPp10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress lags(1)
replace nURntl1GDP2_p5 = nURntl1GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl1GDP2_p10 = nURntl1GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress lags(2)
replace nURntl2GDP2_p5 = nURntl2GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl2GDP2_p10 = nURntl2GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap2 if ccode == 862, regress lags(3)
replace nURntl3GDP2_p5 = nURntl3GDP2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl3GDP2_p10 = nURntl3GDP2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress lags(1)
replace nURntl1GDP3_p5 = nURntl1GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl1GDP3_p10 = nURntl1GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress lags(2)
replace nURntl2GDP3_p5 = nURntl2GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl2GDP3_p10 = nURntl2GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller lnPWT_GDPplcap3 if ccode == 862, regress lags(3)
replace nURntl3GDP3_p5 = nURntl3GDP3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace nURntl3GDP3_p10 = nURntl3GDP3_p10 + 1 if r(p) <= 0.1 & ccode == 862


* (2) Engle-Granger test of cointegration


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862
predict res2CONSUM, residual
* twoway (scatter res2CONSUM year if ccode == 862, title("CONSUMResiduals vs year") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear862CONSUM2.png, replace
* twoway (scatter res2CONSUM L.res2CONSUM if ccode == 862, title("CONSUMResiduals vs lagged residuals") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged862CONSUM2.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862
predict res2PROD, residual
* twoway (scatter res2PROD year if ccode == 862, title("PRODResiduals vs year") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear862PROD2.png, replace
* twoway (scatter res2PROD L.res2PROD if ccode == 862, title("PRODResiduals vs lagged residuals") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged862PROD2.png, replace


reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862
predict res3CONSUM, residual
* twoway (scatter res3CONSUM year if ccode == 862, title("Residuals vs year") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear862CONSUM3.png, replace
* twoway (scatter res3CONSUM L.res3CONSUM if ccode == 862, title("Residuals vs lagged residuals") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged862CONSUM3.png, replace

reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862
predict res3PROD, residual
* twoway (scatter res3PROD year if ccode == 862, title("Residuals vs year") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResYear862PROD3.png, replace
* twoway (scatter res3PROD L.res3PROD if ccode == 862, title("Residuals vs lagged residuals") subtitle("ccode == 862") xlabel(#6) ylabel(#5) msymbol(o))
* graph export bycountry/ResLagged862PROD3.png, replace


** see approximated critical values in Table B.9, Hamilton 1994

* with intercept and trend

dfuller res2CONSUM if ccode == 862, regress trend lags(0)
replace Cointl0CONSUM2_p5 = Cointl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl0CONSUM2_p10 = Cointl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2CONSUM if ccode == 862, regress trend lags(1)
replace Cointl1CONSUM2_p5 = Cointl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl1CONSUM2_p10 = Cointl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2CONSUM if ccode == 862, regress trend lags(2)
replace Cointl2CONSUM2_p5 = Cointl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl2CONSUM2_p10 = Cointl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress trend lags(0)
replace Cointl0PROD2_p5 = Cointl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl0PROD2_p10 = Cointl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress trend lags(1)
replace Cointl1PROD2_p5 = Cointl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl1PROD2_p10 = Cointl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress trend lags(2)
replace Cointl2PROD2_p5 = Cointl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl2PROD2_p10 = Cointl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress trend lags(0)
replace Cointl0CONSUM3_p5 = Cointl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl0CONSUM3_p10 = Cointl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress trend lags(1)
replace Cointl1CONSUM3_p5 = Cointl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl1CONSUM3_p10 = Cointl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress trend lags(2)
replace Cointl2CONSUM3_p5 = Cointl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl2CONSUM3_p10 = Cointl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress trend lags(0)
replace Cointl0PROD3_p5 = Cointl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl0PROD3_p10 = Cointl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress trend lags(1)
replace Cointl1PROD3_p5 = Cointl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl1PROD3_p10 = Cointl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress trend lags(2)
replace Cointl2PROD3_p5 = Cointl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointl2PROD3_p10 = Cointl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862

* with intercept but no trend

dfuller res2CONSUM if ccode == 862, regress lags(0)
replace Cointntl0CONSUM2_p5 = Cointntl0CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl0CONSUM2_p10 = Cointntl0CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2CONSUM if ccode == 862, regress lags(1)
replace Cointntl1CONSUM2_p5 = Cointntl1CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl1CONSUM2_p10 = Cointntl1CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2CONSUM if ccode == 862, regress lags(2)
replace Cointntl2CONSUM2_p5 = Cointntl2CONSUM2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl2CONSUM2_p10 = Cointntl2CONSUM2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress lags(0)
replace Cointntl0PROD2_p5 = Cointntl0PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl0PROD2_p10 = Cointntl0PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress lags(1)
replace Cointntl1PROD2_p5 = Cointntl1PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl1PROD2_p10 = Cointntl1PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res2PROD if ccode == 862, regress lags(2)
replace Cointntl2PROD2_p5 = Cointntl2PROD2_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl2PROD2_p10 = Cointntl2PROD2_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress lags(0)
replace Cointntl0CONSUM3_p5 = Cointntl0CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl0CONSUM3_p10 = Cointntl0CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress lags(1)
replace Cointntl1CONSUM3_p5 = Cointntl1CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl1CONSUM3_p10 = Cointntl1CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3CONSUM if ccode == 862, regress lags(2)
replace Cointntl2CONSUM3_p5 = Cointntl2CONSUM3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl2CONSUM3_p10 = Cointntl2CONSUM3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress lags(0)
replace Cointntl0PROD3_p5 = Cointntl0PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl0PROD3_p10 = Cointntl0PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress lags(1)
replace Cointntl1PROD3_p5 = Cointntl1PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl1PROD3_p10 = Cointntl1PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862
dfuller res3PROD if ccode == 862, regress lags(2)
replace Cointntl2PROD3_p5 = Cointntl2PROD3_p5 + 1 if r(p) <= 0.05 & ccode == 862
replace Cointntl2PROD3_p10 = Cointntl2PROD3_p10 + 1 if r(p) <= 0.1 & ccode == 862


drop res2CONSUM res3CONSUM res2PROD res3PROD

* want no unit roots and cointegration (reject dfuller tests)

log close

save temp1, replace

preserve
keep ccode country nUR* Coint*
duplicates drop
* edit
* analyze in Excel
clear
restore
drop nUR* Coint*


save temp2, replace


* want no unit roots and cointegration (reject dfuller tests)
* if so, perform DOLS



***********
* DOLS
***********


log using neweylog12, replace

****
* ccode == 12
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 12, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 12, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 12, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 12, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 12, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 12, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 12, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 12, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 12, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 12, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 12, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode12oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 12, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode12oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 12, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 12, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode12oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog32, replace

****
* ccode == 32
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 32, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 32, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 32, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 32, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 32, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 32, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 32, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 32, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 32, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 32, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 32, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode32oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 32, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode32oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 32, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 32, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode32oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog36, replace

****
* ccode == 36
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 36, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 36, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 36, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 36, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 36, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 36, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 36, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 36, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 36, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 36, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 36, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode36oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 36, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode36oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 36, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 36, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode36oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog40, replace

****
* ccode == 40
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 40, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 40, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 40, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 40, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 40, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 40, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 40, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 40, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 40, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 40, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 40, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode40oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 40, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode40oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 40, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 40, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode40oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog50, replace

****
* ccode == 50
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 50, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 50, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 50, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 50, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 50, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 50, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 50, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 50, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 50, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 50, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 50, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode50oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 50, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode50oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 50, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 50, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode50oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog56, replace

****
* ccode == 56
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 56, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 56, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 56, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 56, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 56, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 56, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 56, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 56, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 56, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 56, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 56, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode56oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 56, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode56oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 56, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 56, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode56oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog68, replace

****
* ccode == 68
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 68, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 68, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 68, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 68, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 68, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 68, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 68, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 68, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 68, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 68, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 68, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode68oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 68, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode68oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 68, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 68, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode68oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog100, replace
***** 
***** ****
***** * ccode == 100
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 100, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 100, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 100, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 100, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 100, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 100, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 100, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 100, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 100, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 100, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 100, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode100oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 100, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode100oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 100, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 100, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode100oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog120, replace

****
* ccode == 120
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 120, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 120, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 120, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 120, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 120, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 120, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 120, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 120, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 120, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 120, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 120, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode120oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 120, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode120oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 120, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 120, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode120oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog124, replace

****
* ccode == 124
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 124, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 124, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 124, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 124, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 124, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 124, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 124, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 124, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 124, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 124, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 124, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode124oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 124, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode124oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 124, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 124, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode124oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog144, replace

****
* ccode == 144
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 144, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 144, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 144, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 144, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 144, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 144, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 144, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 144, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 144, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 144, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 144, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode144oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 144, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode144oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 144, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 144, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode144oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog152, replace

****
* ccode == 152
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 152, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 152, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 152, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 152, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 152, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 152, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 152, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 152, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 152, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 152, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 152, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode152oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 152, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode152oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 152, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 152, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode152oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog156, replace

****
* ccode == 156
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 156, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 156, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 156, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 156, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 156, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 156, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 156, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 156, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 156, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 156, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 156, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode156oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 156, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode156oil2nl2.png, replace


twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("China")
graph export bycountry/ChinaNeweyl2.png, replace

drop oilCONSUMpred oilPRODpred





est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 156, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 156, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode156oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog158, replace

****
* ccode == 158
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 158, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 158, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 158, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 158, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 158, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 158, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 158, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 158, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 158, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 158, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 158, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode158oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 158, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode158oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 158, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 158, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode158oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog170, replace

****
* ccode == 170
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 170, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 170, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 170, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 170, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 170, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 170, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 170, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 170, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 170, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 170, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 170, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode170oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 170, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode170oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 170, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 170, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode170oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog178, replace
***** 
***** ****
***** * ccode == 178
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 178, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 178, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 178, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 178, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 178, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 178, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 178, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 178, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 178, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 178, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 178, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode178oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 178, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode178oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 178, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 178, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode178oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog188, replace

****
* ccode == 188
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 188, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 188, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 188, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 188, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 188, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 188, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 188, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 188, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 188, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 188, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 188, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode188oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 188, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode188oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 188, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 188, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode188oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog196, replace

****
* ccode == 196
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 196, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 196, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 196, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 196, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 196, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 196, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 196, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 196, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 196, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 196, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 196, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode196oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 196, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode196oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 196, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 196, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode196oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog208, replace

****
* ccode == 208
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 208, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 208, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 208, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 208, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 208, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 208, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 208, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 208, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 208, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 208, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 208, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode208oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 208, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode208oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 208, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 208, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode208oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog214, replace
***** 
***** ****
***** * ccode == 214
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 214, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 214, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 214, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 214, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 214, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 214, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 214, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 214, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 214, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 214, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 214, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode214oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 214, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode214oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 214, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 214, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode214oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog218, replace

****
* ccode == 218
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 218, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 218, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 218, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 218, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 218, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 218, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 218, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 218, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 218, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 218, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 218, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode218oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 218, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode218oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 218, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 218, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode218oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog222, replace

****
* ccode == 222
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 222, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 222, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 222, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 222, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 222, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 222, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 222, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 222, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 222, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 222, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 222, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode222oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 222, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode222oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 222, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 222, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode222oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog246, replace

****
* ccode == 246
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 246, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 246, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 246, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 246, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 246, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 246, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 246, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 246, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 246, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 246, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 246, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode246oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 246, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode246oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 246, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 246, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode246oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog250, replace

****
* ccode == 250
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 250, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 250, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 250, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 250, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 250, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 250, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 250, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 250, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 250, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 250, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 250, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode250oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 250, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode250oil2nl2.png, replace

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("France")
graph export bycountry/FranceNeweyl2.png, replace


drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 250, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 250, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode250oil2reg.png, replace
drop oilCONSUMpred oilPRODpred



***** 
***** log using neweylog288, replace
***** 
***** ****
***** * ccode == 288
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 288, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 288, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 288, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 288, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 288, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 288, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 288, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 288, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 288, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 288, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 288, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode288oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 288, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode288oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 288, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 288, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode288oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog300, replace

****
* ccode == 300
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 300, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 300, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 300, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 300, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 300, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 300, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 300, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 300, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 300, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 300, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 300, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode300oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 300, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode300oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 300, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 300, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode300oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog320, replace
***** 
***** ****
***** * ccode == 320
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 320, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 320, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 320, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 320, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 320, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 320, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 320, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 320, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 320, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 320, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 320, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode320oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 320, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode320oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 320, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 320, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode320oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog340, replace

****
* ccode == 340
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 340, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 340, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 340, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 340, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 340, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 340, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 340, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 340, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 340, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 340, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
* suest oil2CONSUMreg oil2PRODreg
* test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
* test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
* matrix not positive definite


* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
* suest oil2CONSUMreg oil2PRODreg
* testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
* matrix not positive definite

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 340, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode340oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 340, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode340oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 340, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 340, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode340oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog348, replace

****
* ccode == 348
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 348, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 348, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 348, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 348, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 348, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 348, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 348, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 348, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 348, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 348, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 348, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode348oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 348, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode348oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 348, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 348, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode348oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog356, replace

****
* ccode == 356
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 356, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 356, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 356, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 356, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 356, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 356, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 356, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 356, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 356, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 356, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 356, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode356oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 356, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode356oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 356, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 356, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode356oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog360, replace

****
* ccode == 360
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 360, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 360, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 360, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 360, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 360, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 360, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 360, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 360, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 360, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 360, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 360, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode360oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 360, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode360oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 360, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 360, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode360oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog364, replace

****
* ccode == 364
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 364, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 364, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 364, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 364, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 364, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 364, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 364, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 364, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 364, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 364, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 364, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode364oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 364, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode364oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 364, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 364, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode364oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog372, replace

****
* ccode == 372
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 372, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 372, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 372, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 372, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 372, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 372, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 372, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 372, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 372, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 372, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 372, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode372oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 372, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode372oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 372, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 372, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode372oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog376, replace

****
* ccode == 376
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 376, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 376, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 376, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 376, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 376, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 376, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 376, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 376, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 376, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 376, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 376, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode376oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 376, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode376oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 376, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 376, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode376oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog380, replace

****
* ccode == 380
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 380, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 380, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 380, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 380, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 380, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 380, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 380, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 380, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 380, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 380, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 380, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode380oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 380, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode380oil2nl2.png, replace

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("Italy")
graph export bycountry/ItalyNeweyl2.png, replace



drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 380, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 380, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode380oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog384, replace

****
* ccode == 384
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 384, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 384, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 384, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 384, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 384, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 384, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 384, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 384, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 384, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 384, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 384, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode384oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 384, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode384oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 384, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 384, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode384oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog388, replace

****
* ccode == 388
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 388, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 388, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 388, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 388, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 388, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 388, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 388, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 388, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 388, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 388, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 388, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode388oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 388, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode388oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 388, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 388, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode388oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog392, replace

****
* ccode == 392
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 392, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 392, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 392, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 392, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 392, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 392, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 392, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 392, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 392, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 392, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 392, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode392oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 392, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode392oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 392, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 392, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode392oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog400, replace

****
* ccode == 400
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 400, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 400, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 400, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 400, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 400, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 400, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 400, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 400, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 400, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 400, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 400, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode400oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 400, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode400oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 400, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 400, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode400oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog404, replace

****
* ccode == 404
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 404, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 404, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 404, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 404, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 404, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 404, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 404, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 404, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 404, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 404, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 404, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode404oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 404, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode404oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 404, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 404, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode404oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog410, replace

****
* ccode == 410
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 410, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 410, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 410, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 410, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 410, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 410, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 410, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 410, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 410, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 410, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 410, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode410oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 410, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode410oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 410, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 410, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode410oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog458, replace

****
* ccode == 458
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 458, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 458, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 458, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 458, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 458, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 458, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 458, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 458, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 458, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 458, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 458, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode458oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 458, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode458oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 458, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 458, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode458oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog484, replace

****
* ccode == 484
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 484, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 484, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 484, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 484, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 484, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 484, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 484, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 484, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 484, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 484, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 484, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode484oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 484, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode484oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 484, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 484, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode484oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog504, replace

****
* ccode == 504
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 504, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 504, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 504, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 504, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 504, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 504, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 504, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 504, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 504, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 504, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 504, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode504oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 504, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode504oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 504, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 504, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode504oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog528, replace

****
* ccode == 528
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 528, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 528, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 528, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 528, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 528, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 528, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 528, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 528, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 528, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 528, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 528, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode528oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 528, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode528oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 528, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 528, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode528oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog554, replace

****
* ccode == 554
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 554, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 554, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 554, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 554, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 554, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 554, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 554, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 554, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 554, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 554, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 554, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode554oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 554, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode554oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 554, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 554, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode554oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog558, replace
***** 
***** ****
***** * ccode == 558
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 558, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 558, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 558, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 558, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 558, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 558, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 558, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 558, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 558, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 558, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 558, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode558oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 558, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode558oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 558, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 558, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode558oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog566, replace

****
* ccode == 566
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 566, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 566, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 566, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 566, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 566, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 566, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 566, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 566, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 566, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 566, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 566, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode566oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 566, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode566oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 566, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 566, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode566oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog578, replace

****
* ccode == 578
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 578, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 578, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 578, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 578, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 578, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 578, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 578, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 578, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 578, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 578, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 578, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode578oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 578, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode578oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 578, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 578, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode578oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog586, replace

****
* ccode == 586
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 586, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 586, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 586, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 586, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 586, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 586, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 586, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 586, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 586, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 586, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 586, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode586oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 586, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode586oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 586, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 586, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode586oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog590, replace

****
* ccode == 590
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 590, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 590, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 590, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 590, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 590, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 590, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 590, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 590, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 590, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 590, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 590, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode590oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 590, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode590oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 590, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 590, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode590oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog604, replace

****
* ccode == 604
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 604, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 604, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 604, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 604, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 604, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 604, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 604, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 604, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 604, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 604, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 604, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode604oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 604, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode604oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 604, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 604, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode604oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog608, replace

****
* ccode == 608
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 608, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 608, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 608, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 608, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 608, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 608, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 608, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 608, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 608, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 608, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 608, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode608oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 608, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode608oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 608, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 608, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode608oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog616, replace

****
* ccode == 616
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 616, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 616, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 616, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 616, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 616, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 616, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 616, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 616, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 616, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 616, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 616, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode616oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 616, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode616oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 616, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 616, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode616oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog620, replace

****
* ccode == 620
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 620, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 620, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 620, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 620, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 620, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 620, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 620, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 620, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 620, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 620, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 620, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode620oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 620, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode620oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 620, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 620, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode620oil2reg.png, replace
drop oilCONSUMpred oilPRODpred


***** 
***** 
***** log using neweylog642, replace
***** 
***** ****
***** * ccode == 642
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 642, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 642, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 642, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 642, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 642, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 642, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 642, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 642, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 642, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 642, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 642, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode642oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 642, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode642oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 642, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 642, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode642oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred


***** 
***** 
***** log using neweylog643, replace
***** 
***** ****
***** * ccode == 643
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 643, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 643, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 643, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 643, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 643, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 643, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 643, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 643, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 643, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 643, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 643, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode643oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 643, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode643oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 643, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 643, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode643oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 



log using neweylog686, replace

****
* ccode == 686
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 686, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 686, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 686, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 686, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 686, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 686, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 686, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 686, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 686, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 686, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 686, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode686oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 686, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode686oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 686, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 686, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode686oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog702, replace

****
* ccode == 702
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 702, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 702, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 702, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 702, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 702, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 702, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 702, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 702, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 702, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 702, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 702, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode702oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 702, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode702oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 702, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 702, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode702oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog705, replace
***** 
***** ****
***** * ccode == 705
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 705, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 705, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 705, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 705, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 705, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 705, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 705, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 705, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 705, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 705, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 705, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode705oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 705, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode705oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 705, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 705, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode705oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 



log using neweylog710, replace

****
* ccode == 710
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 710, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 710, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 710, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 710, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 710, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 710, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 710, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 710, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 710, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 710, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 710, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode710oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 710, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode710oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 710, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 710, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode710oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog724, replace

****
* ccode == 724
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 724, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 724, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 724, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 724, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 724, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 724, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 724, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 724, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 724, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 724, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 724, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode724oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 724, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode724oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 724, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 724, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode724oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog752, replace

****
* ccode == 752
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 752, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 752, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 752, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 752, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 752, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 752, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 752, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 752, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 752, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 752, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 752, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode752oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 752, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode752oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 752, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 752, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode752oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




***** log using neweylog756, replace
***** 
***** ****
***** * ccode == 756
***** ****
***** 
***** * DOLS
***** 
***** * quadratic:
***** 
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 756, lag(1) force
***** est store oil2CONSUMnl1
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 756, lag(2) force
***** est store oil2CONSUMnl2
***** * for comparison
***** reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756
***** est store oil2CONSUMreg
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756, lag(1) force
***** newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756, lag(2) force
***** 
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 756, lag(1) force
***** est store oil2PRODnl1
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 756, lag(2) force
***** est store oil2PRODnl2
***** * for comparison
***** reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756
***** est store oil2PRODreg
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756, lag(1) force
***** newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 756, lag(2) force
***** 
***** * cubic:
***** 
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 756, lag(1) force
***** * est store oil3CONSUMnl1
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 756, lag(2) force
***** * est store oil3CONSUMnl2
***** * for comparison
***** * reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756
***** * est store oil3CONSUMreg
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756, lag(1) force
***** * newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756, lag(2) force
***** 
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 756, lag(1) force
***** * est store oil3PRODnl1
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 756, lag(2) force
***** * est store oil3PRODnl2
***** * for comparison
***** * reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756
***** * est store oil3PRODreg
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756, lag(1) force
***** * newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 756, lag(2) force
***** 
***** 
***** * calculate peaks
***** 
***** * quadratic
***** 
***** est restore oil2CONSUMnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2CONSUMreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** est restore oil2PRODnl1
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODnl2
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** est restore oil2PRODreg
***** nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
***** 
***** * cubic
***** 
***** * est restore oil3CONSUMnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3CONSUMreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** * est restore oil3PRODnl1
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODnl2
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** * est restore oil3PRODreg
***** * nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
***** 
***** 
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** * test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
***** 
***** * test equality of slopes
***** 
***** * quadratic
***** suest oil2CONSUMreg oil2PRODreg
***** testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))
***** 
***** * cubic
***** * suest oil3CONSUMreg oil3PRODreg
***** * testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))
***** 
***** 
***** log close
***** 
***** 
***** * quadratic graphs
***** 
***** est restore oil2CONSUMnl1
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl1
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 756, oil2CONSUMnl1 and oil2PRODnl1")
***** graph export bycountry/ccode756oil2nl1.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMnl2
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODnl2
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 756, oil2CONSUMnl2 and oil2PRODnl2")
***** graph export bycountry/ccode756oil2nl2.png, replace
***** drop oilCONSUMpred oilPRODpred
***** 
***** 
***** 
***** est restore oil2CONSUMreg
***** predict Cp
***** gen oilCONSUMpred = exp(Cp)
***** drop Cp
***** 
***** est restore oil2PRODreg
***** predict Pp
***** gen oilPRODpred = exp(Pp)
***** drop Pp
***** 
***** twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 756, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 756, oil2CONSUMreg and oil2PRODreg")
***** graph export bycountry/ccode756oil2reg.png, replace
***** drop oilCONSUMpred oilPRODpred




log using neweylog760, replace

****
* ccode == 760
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 760, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 760, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 760, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 760, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 760, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 760, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 760, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 760, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 760, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 760, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 760, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode760oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 760, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode760oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 760, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 760, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode760oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog788, replace

****
* ccode == 788
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 788, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 788, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 788, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 788, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 788, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 788, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 788, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 788, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 788, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 788, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 788, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode788oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 788, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode788oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 788, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 788, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode788oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog792, replace

****
* ccode == 792
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 792, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 792, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 792, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 792, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 792, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 792, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 792, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 792, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 792, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 792, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 792, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode792oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 792, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode792oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 792, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 792, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode792oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog818, replace

****
* ccode == 818
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 818, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 818, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 818, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 818, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 818, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 818, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 818, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 818, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 818, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 818, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 818, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode818oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 818, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode818oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 818, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 818, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode818oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog826, replace

****
* ccode == 826
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 826, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 826, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 826, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 826, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 826, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 826, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 826, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 826, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 826, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 826, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 826, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode826oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 826, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode826oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 826, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 826, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode826oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog834, replace

****
* ccode == 834
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 834, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 834, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 834, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 834, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 834, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 834, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 834, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 834, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 834, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 834, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 834, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode834oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 834, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode834oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 834, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 834, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode834oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog840, replace

****
* ccode == 840
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 840, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 840, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 840, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 840, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 840, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 840, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 840, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 840, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 840, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 840, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 840, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode840oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 840, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode840oil2nl2.png, replace

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("USA")
graph export bycountry/USANeweyl2.png, replace



drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 840, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 840, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode840oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog858, replace

****
* ccode == 858
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 858, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 858, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 858, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 858, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 858, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 858, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 858, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 858, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 858, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 858, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 858, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode858oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 858, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode858oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 858, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 858, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode858oil2reg.png, replace
drop oilCONSUMpred oilPRODpred




log using neweylog862, replace

****
* ccode == 862
****

* DOLS

* quadratic:

newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 862, lag(1) force
est store oil2CONSUMnl1
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 862, lag(2) force
est store oil2CONSUMnl2
* for comparison
reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862
est store oil2CONSUMreg
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862, lag(1) force
newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862, lag(2) force

newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 if ccode == 862, lag(1) force
est store oil2PRODnl1
newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 if ccode == 862, lag(2) force
est store oil2PRODnl2
* for comparison
reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862
est store oil2PRODreg
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862, lag(1) force
newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 if ccode == 862, lag(2) force

* cubic:

* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 862, lag(1) force
* est store oil3CONSUMnl1
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 862, lag(2) force
* est store oil3CONSUMnl2
* for comparison
* reg lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862
* est store oil3CONSUMreg
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862, lag(1) force
* newey lnoilCONSUMbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862, lag(2) force

* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 if ccode == 862, lag(1) force
* est store oil3PRODnl1
* newey lnoilPRODbarrelscap lnPWT_GDPplcap S.lnPWT_GDPplcap S2.lnPWT_GDPplcap lnPWT_GDPplcapF1 lnPWT_GDPplcapF2 lnPWT_GDPplcap2 S.lnPWT_GDPplcap2 S2.lnPWT_GDPplcap2 lnPWT_GDPplcap2F1 lnPWT_GDPplcap2F2 lnPWT_GDPplcap3 S.lnPWT_GDPplcap3 S2.lnPWT_GDPplcap3 lnPWT_GDPplcap3F1 lnPWT_GDPplcap3F2 if ccode == 862, lag(2) force
* est store oil3PRODnl2
* for comparison
* reg lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862
* est store oil3PRODreg
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862, lag(1) force
* newey lnoilPRODbarrelscap lnPWT_GDPplcap lnPWT_GDPplcap2 lnPWT_GDPplcap3 if ccode == 862, lag(2) force


* calculate peaks

* quadratic

est restore oil2CONSUMnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2CONSUMreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

est restore oil2PRODnl1
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODnl2
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))
est restore oil2PRODreg
nlcom exp(-_b[lnPWT_GDPplcap]/(2 * _b[lnPWT_GDPplcap2]))

* cubic

* est restore oil3CONSUMnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3CONSUMreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))

* est restore oil3PRODnl1
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODnl2
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))
* est restore oil3PRODreg
* nlcom exp((-2 * _b[lnPWT_GDPplcap2] - sqrt(4 * (_b[lnPWT_GDPplcap2])^2 - (12 * _b[lnPWT_GDPplcap] * _b[lnPWT_GDPplcap3])))/(6 * _b[lnPWT_GDPplcap3]))



* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
test ([oil2CONSUMreg_mean]_cons = [oil2PRODreg_mean]_cons) ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)
test ([oil2CONSUMreg_mean]lnPWT_GDPplcap = [oil2PRODreg_mean]lnPWT_GDPplcap) ([oil2CONSUMreg_mean]lnPWT_GDPplcap2 = [oil2PRODreg_mean]lnPWT_GDPplcap2)

* cubic
* suest oil3CONSUMreg oil3PRODreg
* test ([oil3CONSUMreg_mean]_cons = [oil3PRODreg_mean]_cons) ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)
* test ([oil3CONSUMreg_mean]lnPWT_GDPplcap = [oil3PRODreg_mean]lnPWT_GDPplcap) ([oil3CONSUMreg_mean]lnPWT_GDPplcap2 = [oil3PRODreg_mean]lnPWT_GDPplcap2) ([oil3CONSUMreg_mean]lnPWT_GDPplcap3 = [oil3PRODreg_mean]lnPWT_GDPplcap3)

* test equality of slopes

* quadratic
suest oil2CONSUMreg oil2PRODreg
testnl(exp(-[oil2PRODreg_mean]lnPWT_GDPplcap/(2 * [oil2PRODreg_mean]lnPWT_GDPplcap2)) = exp(-[oil2CONSUMreg_mean]lnPWT_GDPplcap/(2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2)))

* cubic
* suest oil3CONSUMreg oil3PRODreg
* testnl (exp((-2 * [oil2PRODreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2PRODreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2PRODreg_mean]lnPWT_GDPplcap * [oil2PRODreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2PRODreg_mean]lnPWT_GDPplcap3)) = exp((-2 * [oil2CONSUMreg_mean]lnPWT_GDPplcap2 - sqrt(4 * ([oil2CONSUMreg_mean]lnPWT_GDPplcap2)^2 - (12 * [oil2CONSUMreg_mean]lnPWT_GDPplcap * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))/(6 * [oil2CONSUMreg_mean]lnPWT_GDPplcap3)))


log close


* quadratic graphs

est restore oil2CONSUMnl1
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl1
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 862, oil2CONSUMnl1 and oil2PRODnl1")
graph export bycountry/ccode862oil2nl1.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMnl2
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODnl2
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 862, oil2CONSUMnl2 and oil2PRODnl2")
graph export bycountry/ccode862oil2nl2.png, replace
drop oilCONSUMpred oilPRODpred



est restore oil2CONSUMreg
predict Cp
gen oilCONSUMpred = exp(Cp)
drop Cp

est restore oil2PRODreg
predict Pp
gen oilPRODpred = exp(Pp)
drop Pp

twoway (scatter oilCONSUMpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(o) xtitle("GDP per capita") ytitle("barrels of oil per capita per day") legend(label(1 "Consumption"))) (scatter oilPRODpred PWT_GDPplcap if ccode == 862, xlabel(#6) ylabel(#5) msymbol(+) legend(label(2 "Production"))), legend(position(6) region(lstyle(none) lcolor(none))) title("Consumption and Production EKCs for Oil") subtitle("ccode == 862, oil2CONSUMreg and oil2PRODreg")
graph export bycountry/ccode862oil2reg.png, replace
drop oilCONSUMpred oilPRODpred
